@@ -14,7 +14,7 @@ Output:
 	Return value.
 
 Return value:
-	Absolute value (double value).
+	Absolute value (positive double value).
 
 ========includes:============================================================*/
 
