@@ -1,4 +1,4 @@
-/* Copyright (C) 2000 Damir Zucic */
+/* Copyright (C) 2000-2002 Damir Zucic */
 
 /*=============================================================================
 
@@ -40,7 +40,7 @@ void		ErrorMessage_ (char *, char *, char *,
 
 ConfigS *AllocateConfigS_ (void)
 {
-ConfigS		*configSP;
+static ConfigS		*configSP;
 
 /* Allocate zero-initialized memory: */
 configSP = (ConfigS *) calloc (1, sizeof (ConfigS));
