@@ -1,4 +1,4 @@
-/* Copyright (C) 2000 Damir Zucic */
+/* Copyright (C) 2000-2002 Damir Zucic */
 
 /*=============================================================================
 
@@ -40,7 +40,7 @@ void		ErrorMessage_ (char *, char *, char *,
 
 GUIS *AllocateGUIS_ (void)
 {
-GUIS		*guiSP;
+static GUIS		*guiSP;
 
 /* Allocate zero-initialized memory: */
 guiSP = (GUIS *) calloc (1, sizeof (GUIS));
