@@ -143,7 +143,10 @@ double		sin_angle, cos_angle;
 /*------check the number of residues:----------------------------------------*/
 
 /* The minimal number of residues is equal to the sliding window width: */
-if (mol_complexSP->residuesN < runtimeSP->sliding_window_width) return -1;
+if ((int) mol_complexSP->residuesN < runtimeSP->sliding_window_width)
+	{
+	return -1;
+	}
 
 /*------copy the sequence:---------------------------------------------------*/
 
@@ -188,7 +191,7 @@ runtimeSP->residuesN = residuesN;
 scaleI = runtimeSP->hydrophobicity_scaleI;
 
 /* Scan the general purpose sequence: */
-for (residueI = 0; residueI < runtimeSP->residuesN; residueI++)
+for (residueI = 0; residueI < (int) runtimeSP->residuesN; residueI++)
 	{
 	/* Pointer to the current residue name: */
 	residue_nameP = runtimeSP->sequenceP + residueI * max_length;
