@@ -146,7 +146,6 @@ Notes:
 
 /*======function prototypes:=================================================*/
 
-double		Hydrophobicity_ (char *, int, int);
 int		ExtractCA_ (VectorS *, AtomS *, size_t, size_t);
 int		ExtractCACB_ (VectorS *, VectorS *, AtomS *, size_t, size_t);
 double		ScalarProduct_ (VectorS *, VectorS *);
@@ -298,7 +297,7 @@ simple_index_offset = simple_cells_along_axisN / 2;
 atomsN = mol_complexSP->atomsN;
 if (atomsN == 0) return -2;
 
-/* Copy and check the number of residues and the number of atoms: */
+/* Copy and check the number of residues: */
 residuesN = mol_complexSP->residuesN;
 if (residuesN < window_width) return -3;
 
