@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2002 Damir Zucic */
+/* Copyright (C) 2000-2003 Damir Zucic */
 
 /*=============================================================================
 
@@ -184,7 +184,10 @@ for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 		    {
 		    /* Check vertical position: */
 		    if (screen_y < 0) continue;
-		    if (screen_y >= guiSP->main_win_free_area_height) continue;
+		    if (screen_y >= (int) guiSP->main_win_free_area_height)
+			{
+			continue;
+			}
 
 		    /* Check distance from the circle center: */
 		    delta_x = (long) (screen_x - screen_x0);
@@ -318,7 +321,10 @@ for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 		    {
 		    /* Check vertical position: */
 		    if (screen_y < 0) continue;
-		    if (screen_y >= guiSP->main_win_free_area_height) continue;
+		    if (screen_y >= (int) guiSP->main_win_free_area_height)
+			{
+			continue;
+			}
 
 		    /* Check distance from the circle center: */
 		    delta_x = (long) (screen_x - screen_x0);
