@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2002 Damir Zucic */
+/* Copyright (C) 2000-2006 Damir Zucic */
 
 /*=============================================================================
 
@@ -6,8 +6,9 @@
 
 Purpose:
 	Execute bonds command: change the bond drawing style for selected
-	atoms.  Do not change  drawing style for  hydrogen and  disulfide
-	bonds. Do it for pseudo-bonds.
+	atoms or refresh bonds.  Do not change drawing style for hydrogen
+	and disulfide bonds.  Change it  for pseudo-bonds.  Refreshing is
+	however done for ordinary, disulfide and pseudo-bonds.
 
 Input:
 	(1) Pointer to MolComplexS structure, with macromol. complexes.
@@ -28,6 +29,12 @@ Return value:
 	(1) Positive (command) code on success.
 	(2) Negative (error) code on failure.
 
+Notes:
+	(1) Bonds sometimes should be refreshed after replacement of side
+	    chains, creation of a new structure and after moving atoms or
+	    groups of atoms.  Move (rotate) badly placed side chains into
+	    a proper position (far from all neighbors) before refreshing.
+ 
 ========includes:============================================================*/
 
 #include <stdio.h>
@@ -46,6 +53,11 @@ Return value:
 /*======function prototypes:=================================================*/
 
 char		*ExtractToken_ (char *, int, char *, char *);
+size_t		StrongBonds_ (MolComplexS *, int, ConfigS *);
+size_t		PseudoBonds_ (MolComplexS *, int, ConfigS *);
+size_t		DisulfideBonds_ (MolComplexS *, int, ConfigS *);
+int		RefreshBackbone_ (MolComplexS *, ConfigS *);
+int		DihedralAngles_ (MolComplexS *, ConfigS *);
 size_t		MainRefresh_ (MolComplexS *, int,
 			      RuntimeS *, ConfigS *, GUIS *,
 			      NearestAtomS *, size_t, unsigned int);
@@ -63,6 +75,7 @@ char		*remainderP;
 char		tokenA[SHORTSTRINGSIZE];
 int		bond_styleI;
 int		mol_complexI;
+MolComplexS	*default_mol_complexSP;
 MolComplexS	*curr_mol_complexSP;
 size_t		atomsN, atomI;
 AtomS		*curr_atomSP;
@@ -79,7 +92,8 @@ if (!remainderP)
 	return ERROR_NO_ATOM_STYLE;
 	}
 
-/* Try to recognize the requested style: */
+/* The tokenA should either define the new bond */
+/* style  or contain request  to refresh bonds: */
 if      (strcmp (tokenA, "0")   == 0) bond_styleI = 0;
 else if (strcmp (tokenA, "1")   == 0) bond_styleI = 1;
 else if (strcmp (tokenA, "2")   == 0) bond_styleI = 2;
@@ -88,6 +102,7 @@ else if (strcmp (tokenA, "4")   == 0) bond_styleI = 4;
 else if (strcmp (tokenA, "5")   == 0) bond_styleI = 5;
 else if (strstr (tokenA, "NIC") == tokenA) bond_styleI = NICE_BONDS;
 else if (strstr (tokenA, "STI") == tokenA) bond_styleI = STICK_BONDS;
+else if (strstr (tokenA, "REF") == tokenA) bond_styleI = REFRESH_BONDS;
 else
 	{
 	sprintf (runtimeSP->messageA,
@@ -96,6 +111,47 @@ else
 	return ERROR_BOND_STYLE;
 	}
 
+/* The special case - request to refresh bonds: */
+if (bond_styleI == REFRESH_BONDS)
+	{
+	/* Prepare the pointer to default complex: */
+	default_mol_complexSP = mol_complexSP + runtimeSP->default_complexI;
+
+	/* Update strong bonds: */
+	StrongBonds_ (default_mol_complexSP,
+		      runtimeSP->default_complexI, configSP);
+
+	/* Update pseudo-bonds: */
+	PseudoBonds_ (default_mol_complexSP,
+		      runtimeSP->default_complexI, configSP);
+
+	/* Prepare disulfide bonds: */
+	DisulfideBonds_ (default_mol_complexSP,
+			 runtimeSP->default_complexI, configSP);
+
+	/* Refresh backbone data: */
+	RefreshBackbone_ (default_mol_complexSP, configSP);
+
+	/* Calculate dihedral angles and cis-trans flags: */
+	DihedralAngles_ (default_mol_complexSP, configSP);
+
+	/* Reset the position_changedF: */
+	default_mol_complexSP->position_changedF = 1;
+
+	/* Refresh the main window: */
+	(*refreshIP)++;
+	MainRefresh_ (mol_complexSP, mol_complexesN,
+		      runtimeSP, configSP, guiSP,
+		      nearest_atomSP, pixelsN, *refreshIP);
+
+	/* Refresh the control window: */
+	ControlRefresh_ (mol_complexSP + runtimeSP->default_complexI,
+			 configSP, guiSP);
+
+	/* Return positive value on success: */
+	return COMMAND_BONDS;
+	}
+
 /* Scan every macromolecular complex: */
 for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 	{
