@@ -1,4 +1,4 @@
-/* Copyright (C) 2001 Damir Zucic */
+/* Copyright (C) 2001-2003 Damir Zucic */
 
 /*=============================================================================
 
@@ -171,7 +171,10 @@ for (localI = 0; localI < 20; localI++)
 	screen_y0 += line_height;
 
 	/* Do not draw text if it falls outside the output window: */
-	if (screen_y0 > guiSP->output_winS.height + line_height) continue;
+	if (screen_y0 > (int) guiSP->output_winS.height + line_height)
+		{
+		continue;
+		}
 
 	/* Prepare and check local indices for both sequences: */
 	ref_residueI = first_ref_residueI + localI;
