@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2004 Damir Zucic */
+/* Copyright (C) 2000-2006 Damir Zucic */
 
 /*=============================================================================
 
@@ -10,6 +10,7 @@ Purpose:
 	buffer is used to calculate requested functions. More plots may be
 	drawn simultaneosly. The following functions are available:
 	- average hydrophobicity;
+	- weighted hydrophobicity;
 	- hydrophobic moment;
 	- two sided hydrophobicity profiles (larger and smaller);
 	- hydrophobicity function F1.
@@ -48,6 +49,10 @@ Notes:
 	    ensures  that the sum  of two values  is equal to  the average
 	    hydrophobicity value.
 
+	(4) Red color is used to draw both  the average hydrophobicity and
+	    the function F6.  Blue color is used to draw both the hydroph.
+	    moment and the function F7.
+
 ========includes:============================================================*/
 
 #include <stdio.h>
@@ -69,11 +74,14 @@ int		RefreshPixmap_ (Display *, Pixmap, GC,
 				unsigned int, unsigned int, unsigned long);
 int		ParseColor_ (RGBS *, unsigned long *, GUIS *, char *, char *);
 int		AverageHydrophobicity_ (double *, double *, RuntimeS *);
+int		WeightedHydrophobicity_ (double *, double *, RuntimeS *);
 int		HyphobFunction1_ (double *, double *, RuntimeS *);
 int		HyphobFunction2_ (double *, double *, RuntimeS *);
 int		HyphobFunction3_ (double *, double *, RuntimeS *);
 int		HyphobFunction4_ (double *, double *, RuntimeS *);
 int		HyphobFunction5_ (double *, double *, RuntimeS *);
+int		HyphobFunction6_ (double *, double *, RuntimeS *);
+int		HyphobFunction7_ (double *, double *, RuntimeS *);
 
 /*======draw hydrophobicity plots:===========================================*/
 
@@ -87,8 +95,10 @@ int		range_startI, range_endI, residues_in_plotN = 0;
 int		visible_residueI;
 int		window_width, half_window_width, windowI, combinedI;
 double		angle_step, angle;
-double		hydrophobicity, average_hydrophobicity = 0;
+double		hydrophobicity;
+static double	weighted_hydrophobicity = 0.0, average_hydrophobicity = 0;
 double		min_average_hyphob, max_average_hyphob;
+double		min_weighted_hyphob, max_weighted_hyphob;
 double		hydrophobic_moment, abs_squared, moment_x, moment_y;
 double		min_hyphob_moment, max_hyphob_moment;
 double		min_sided_hyphob, max_sided_hyphob;
@@ -124,6 +134,8 @@ double		min_function2 = 0.0, max_function2 = 0.0, function2;
 double		min_function3 = 0.0, max_function3 = 0.0, function3;
 double		min_function4 = 0.0, max_function4 = 0.0, function4;
 double		min_function5 = 0.0, max_function5 = 0.0, function5;
+double		min_function6 = 0.0, max_function6 = 0.0, function6;
+double		min_function7 = 0.0, max_function7 = 0.0, function7;
 
 /*------prepare some parameters:---------------------------------------------*/
 
@@ -137,14 +149,17 @@ if (residuesN == 0)
 	}
 
 /* Paranoid check - at least one flag should be different from zero: */
-if ((runtimeSP->average_hydrophobicityF == 0) &&
-    (runtimeSP->hydrophobic_momentF     == 0) &&
-    (runtimeSP->sided_hydrophobicityF   == 0) &&
-    (runtimeSP->function1F              == 0) &&
-    (runtimeSP->function2F              == 0) &&
-    (runtimeSP->function3F              == 0) &&
-    (runtimeSP->function4F              == 0) &&
-    (runtimeSP->function5F              == 0)) return 0;
+if ((runtimeSP->average_hydrophobicityF  == 0) &&
+    (runtimeSP->weighted_hydrophobicityF == 0) &&
+    (runtimeSP->hydrophobic_momentF      == 0) &&
+    (runtimeSP->sided_hydrophobicityF    == 0) &&
+    (runtimeSP->function1F               == 0) &&
+    (runtimeSP->function2F               == 0) &&
+    (runtimeSP->function3F               == 0) &&
+    (runtimeSP->function4F               == 0) &&
+    (runtimeSP->function5F               == 0) &&
+    (runtimeSP->function6F               == 0) &&
+    (runtimeSP->function7F               == 0)) return 0;
 
 /* The range of residue array indices: */
 range_startI = runtimeSP->range_startI;
@@ -193,6 +208,14 @@ max_average_hyphob = -999999.0;
 
 AverageHydrophobicity_ (&min_average_hyphob, &max_average_hyphob, runtimeSP);
 
+/*------calculate the weighted hydrophobicity:-------------------------------*/
+
+/* Initialize the extreme values: */
+min_weighted_hyphob = +999999.0;
+max_weighted_hyphob = -999999.0;
+
+WeightedHydrophobicity_ (&min_weighted_hyphob, &max_weighted_hyphob, runtimeSP);
+
 /*------calculate the hydrophobic moment:------------------------------------*/
 
 /* Initialize the extreme values: */
@@ -344,34 +367,45 @@ for (residueI = 0; residueI < residuesN; residueI++)
 		}
 	}
 
+/*------calculate hydrophobicity functions, in reverse order.----------------*/
+
+/* Note: some functions with higher number may call functions with */
+/* lower number - that explains why reverse order  should be used! */
+
+/*------calculate the hydrophobicity function F7:----------------------------*/
+
+if (runtimeSP->function7F)
+	HyphobFunction7_ (&min_function7, &max_function7, runtimeSP);
+
+/*------calculate the hydrophobicity function F6:----------------------------*/
+
+if (runtimeSP->function6F)
+	HyphobFunction6_ (&min_function6, &max_function6, runtimeSP);
+
 /*------calculate the hydrophobicity function F5:----------------------------*/
 
-/* Note: this function calls  HyphobFunction1_ and  HyphobFunction4_ , */
-/* with interface and  octanol hydrophobicity scale,  ignoring default */
-/* hydrophobicity scale. These two functions should be repeated later, */
-/* to prepare  the proper functions  F1 and  F4,  using default scale. */
 if (runtimeSP->function5F)
-        HyphobFunction5_ (&min_function5, &max_function5, runtimeSP);
+	HyphobFunction5_ (&min_function5, &max_function5, runtimeSP);
 
-/*------calculate the hydrophobicity function F1:----------------------------*/
+/*------calculate the hydrophobicity function F4:----------------------------*/
 
-if (runtimeSP->function1F)
-	HyphobFunction1_ (&min_function1, &max_function1, runtimeSP);
-
-/*------calculate the hydrophobicity function F2:----------------------------*/
-
-if (runtimeSP->function2F)
-	HyphobFunction2_ (&min_function2, &max_function2, runtimeSP);
+if (runtimeSP->function4F)
+	HyphobFunction4_ (&min_function4, &max_function4, runtimeSP);
 
 /*------calculate the hydrophobicity function F3:----------------------------*/
 
 if (runtimeSP->function3F)
 	HyphobFunction3_ (&min_function3, &max_function3, runtimeSP);
 
-/*------calculate the hydrophobicity function F4:----------------------------*/
+/*------calculate the hydrophobicity function F2:----------------------------*/
 
-if (runtimeSP->function4F)
-	HyphobFunction4_ (&min_function4, &max_function4, runtimeSP);
+if (runtimeSP->function2F)
+	HyphobFunction2_ (&min_function2, &max_function2, runtimeSP);
+
+/*------calculate the hydrophobicity function F1:----------------------------*/
+
+if (runtimeSP->function1F)
+	HyphobFunction1_ (&min_function1, &max_function1, runtimeSP);
 
 /*------prepare geometric parameters:----------------------------------------*/
 
@@ -559,6 +593,19 @@ if (runtimeSP->average_hydrophobicityF)
 		ordinate_max = max_average_hyphob;
 		}
 	}
+
+if (runtimeSP->weighted_hydrophobicityF)
+	{
+	if (min_weighted_hyphob < ordinate_min)
+		{
+		ordinate_min = min_weighted_hyphob;
+		}
+	if (max_weighted_hyphob > ordinate_max)
+		{
+		ordinate_max = max_weighted_hyphob;
+		}
+	}
+
 if (runtimeSP->hydrophobic_momentF)
 	{
 	if (min_hyphob_moment < ordinate_min)
@@ -570,6 +617,7 @@ if (runtimeSP->hydrophobic_momentF)
 		ordinate_max = max_hyphob_moment;
 		}
 	}
+
 if (runtimeSP->sided_hydrophobicityF)
 	{
 	if (min_sided_hyphob < ordinate_min)
@@ -642,6 +690,30 @@ if (runtimeSP->function5F)
 		}
 	}
 
+if (runtimeSP->function6F)
+	{
+	if (min_function6 < ordinate_min)
+		{
+		ordinate_min = min_function6;
+		}
+	if (max_function6 > ordinate_max)
+		{
+		ordinate_max = max_function6;
+		}
+	}
+
+if (runtimeSP->function7F)
+	{
+	if (min_function7 < ordinate_min)
+		{
+		ordinate_min = min_function7;
+		}
+	if (max_function7 > ordinate_max)
+		{
+		ordinate_max = max_function7;
+		}
+	}
+
 /* Shift both values slightly for esthetic reasons: */
 ordinate_range = ordinate_max - ordinate_min;
 ordinate_min -= 0.15 * ordinate_range; 
@@ -952,6 +1024,158 @@ if (runtimeSP->average_hydrophobicityF)
 		}
 	}
 
+/*------draw weighted hydrophobicity (pink line):----------------------------*/
+
+if (runtimeSP->weighted_hydrophobicityF)
+	{
+	/* Prepare three colors for weighted hydrophobicity: */
+	ParseColor_ (&rgbS, &color1ID, guiSP, "RGB:FFFF/8888/BBBB", "white");
+	ParseColor_ (&rgbS, &color2ID, guiSP, "RGB:FFFF/0000/BBBB", "white");
+	ParseColor_ (&rgbS, &color3ID, guiSP, "RGB:9999/0000/5555", "black");
+	XSetForeground (guiSP->displaySP, guiSP->theGCA[1], color1ID);
+	XSetForeground (guiSP->displaySP, guiSP->theGCA[2], color2ID);
+	XSetForeground (guiSP->displaySP, guiSP->theGCA[3], color3ID);
+
+	/* Reset the counter of visible residues: */
+	visible_residueI = 0;
+
+	/* Scan the sequence: */
+	for (residueI = 0; residueI < residuesN; residueI++)
+		{
+		/* Check is the residue array index inside the range: */
+		if ((residueI < range_startI) || (residueI > range_endI))
+			{
+			continue;
+			}
+
+		/* Copy the weighted hydrophobicity: */
+		weighted_hydrophobicity =
+			(double) *(runtimeSP->weighted_hydrophobicityP +
+				   residueI);
+
+		/* Prepare the section index: */
+		sectionI = visible_residueI / residues_per_sectionN;
+
+		/* Prepare the local residue index: */
+		local_residueI = visible_residueI % residues_per_sectionN;
+
+		/* Prepare screen coordinates: */
+		screen_x0 = screen_margin_x +
+			    local_residueI * residue_screen_width -
+			    half_residue_width - 1;
+		screen_x1 = screen_x0 + residue_screen_width + 2;
+		d = (weighted_hydrophobicity - ordinate_min) * ordinate_scale;
+		screen_y0 = screen_margin_top + sectionI * section_height;
+		screen_y1 = screen_y0 + section_height;
+		screen_y  = screen_y1 - (int) d;
+
+		/* Draw triple line: */
+		XDrawLine (guiSP->displaySP,
+			   guiSP->main_hidden_pixmapID,
+			   guiSP->theGCA[1],
+			   screen_x0, screen_y - 1,
+			   screen_x1, screen_y - 1);
+		XDrawLine (guiSP->displaySP,
+			   guiSP->main_hidden_pixmapID,
+			   guiSP->theGCA[2],
+			   screen_x0, screen_y,
+			   screen_x1, screen_y);
+		XDrawLine (guiSP->displaySP,
+			   guiSP->main_hidden_pixmapID,
+			   guiSP->theGCA[3],
+			   screen_x0, screen_y + 1,
+			   screen_x1, screen_y + 1);
+
+		/* Initialize  the flag  which says is */
+		/* it necessary to draw vertical line: */
+		draw_vertical_lineF = 1;
+
+		/* For  the first residue in  the current */
+		/* section do not draw the vertical line: */
+		if (local_residueI == 0)
+			{
+			old_screen_y = screen_y0;
+			draw_vertical_lineF = 0;
+			}
+
+		/* For the first residue, do not draw the vertical line: */
+		if (residueI == range_startI)
+			{
+			old_screen_y = screen_y;
+			draw_vertical_lineF = 0;
+			}
+
+		/* Check is it necessary to draw vertical line: */
+		if (old_screen_y == screen_y)
+			{
+			old_screen_y = screen_y;
+			draw_vertical_lineF = 0;
+			}
+
+		/* Prepare the shift which is required to draw corners; take */
+		/* the next res. if there is no need to draw vertical lines: */
+		if (old_screen_y < screen_y) shift = -1;
+		else shift = +1;
+
+		/* Draw three vertical lines: */
+		if (draw_vertical_lineF)
+			{
+			XDrawLine (guiSP->displaySP,
+				   guiSP->main_hidden_pixmapID,
+				   guiSP->theGCA[1],
+				   screen_x0, old_screen_y - shift,
+				   screen_x0, screen_y - shift);
+			XDrawLine (guiSP->displaySP,
+				   guiSP->main_hidden_pixmapID,
+				   guiSP->theGCA[2],
+				   screen_x0 + 1, old_screen_y,
+				   screen_x0 + 1, screen_y);
+			XDrawLine (guiSP->displaySP,
+				   guiSP->main_hidden_pixmapID,
+				   guiSP->theGCA[3],
+				   screen_x0 + 2, old_screen_y + shift,
+				   screen_x0 + 2, screen_y + shift);
+			}
+
+		/* Copy the y coordinate for later use: */
+		old_screen_y = screen_y;
+
+		/* Fill NearestAtomS array: */
+		for (screen_x  = screen_x0 + 2;
+		     screen_x <= screen_x1 - 1;
+		     screen_x++)
+			{
+			for (screen_y  = screen_y0;
+			     screen_y <= screen_y1;
+			     screen_y++)
+				{
+				/* Prepare index  to the array */
+				/* of NearestAtomS structures: */
+				pixelI = guiSP->main_win_free_area_width *
+					 screen_y + screen_x;
+
+				/* Check the pixel index: */
+				if (pixelI >= pixelsN) continue;
+
+				/* Pointer to  NearestAtomS struct. */
+				/* assigned to current coordinates: */
+				curr_pixelSP = nearest_atomSP + pixelI;
+
+				/* Refresh NearestAtomS associated with */
+				/* this pixel;  residue index is stored */
+				/* to location reserved for atom index. */
+				curr_pixelSP->last_refreshI = refreshI;
+				curr_pixelSP->atomI = residueI;
+				curr_pixelSP->z = weighted_hydrophobicity;
+				}
+			}
+
+		/* Update the counter of visible residues: */
+		visible_residueI++;
+		}
+	}
+
+
 /*------draw hydrophobic moment (blue line):---------------------------------*/
 
 if (runtimeSP->hydrophobic_momentF)
@@ -2153,6 +2377,306 @@ if (runtimeSP->function5F)
 		}
 	}
 
+/*------draw hydrophobicity function F6 (again red line):--------------------*/
+
+if (runtimeSP->function6F)
+	{
+	/* Prepare three colors for function F6: */
+        /* Prepare three colors for average hydrophobicity: */
+	ParseColor_ (&rgbS, &color1ID, guiSP, "RGB:FFFF/8888/8888", "white");
+	ParseColor_ (&rgbS, &color2ID, guiSP, "RGB:FFFF/0000/0000", "white");
+	ParseColor_ (&rgbS, &color3ID, guiSP, "RGB:8888/0000/0000", "black");
+	XSetForeground (guiSP->displaySP, guiSP->theGCA[1], color1ID);
+	XSetForeground (guiSP->displaySP, guiSP->theGCA[2], color2ID);
+	XSetForeground (guiSP->displaySP, guiSP->theGCA[3], color3ID);
+
+	/* Reset the counter of visible residues: */
+	visible_residueI = 0;
+
+	/* Scan the sequence: */
+	for (residueI = 0; residueI < residuesN; residueI++)
+		{
+		/* Check is the residue array index inside the range: */
+		if ((residueI < range_startI) || (residueI > range_endI))
+			{
+			continue;
+			}
+
+		/* Copy the function value: */
+		function6 = (double) *(runtimeSP->function6P + residueI);
+
+		/* Prepare the section index: */
+		sectionI = visible_residueI / residues_per_sectionN;
+
+		/* Prepare the local residue index: */
+		local_residueI = visible_residueI % residues_per_sectionN;
+
+		/* Prepare screen coordinates: */
+		screen_x0 = screen_margin_x +
+			    local_residueI * residue_screen_width -
+			    half_residue_width - 1;
+		screen_x1 = screen_x0 + residue_screen_width + 2;
+		d = (function6 - ordinate_min) * ordinate_scale;
+		screen_y0 = screen_margin_top + sectionI * section_height;
+		screen_y1 = screen_y0 + section_height;
+		screen_y  = screen_y1 - (int) d;
+
+		/* Draw triple line: */
+		XDrawLine (guiSP->displaySP,
+			   guiSP->main_hidden_pixmapID,
+			   guiSP->theGCA[1],
+			   screen_x0, screen_y - 1,
+			   screen_x1, screen_y - 1);
+		XDrawLine (guiSP->displaySP,
+			   guiSP->main_hidden_pixmapID,
+			   guiSP->theGCA[2],
+			   screen_x0, screen_y,
+			   screen_x1, screen_y);
+		XDrawLine (guiSP->displaySP,
+			   guiSP->main_hidden_pixmapID,
+			   guiSP->theGCA[3],
+			   screen_x0, screen_y + 1,
+			   screen_x1, screen_y + 1);
+
+		/* Initialize  the flag  which says is */
+		/* it necessary to draw vertical line: */
+		draw_vertical_lineF = 1;
+
+		/* For  the first residue in  the current */
+		/* section do not draw the vertical line: */
+		if (local_residueI == 0)
+			{
+			old_screen_y = screen_y0;
+			draw_vertical_lineF = 0;
+			}
+
+		/* For the first residue, do not draw the vertical line: */
+		if (residueI == range_startI)
+			{
+			old_screen_y = screen_y;
+			draw_vertical_lineF = 0;
+			}
+
+		/* Check is it necessary to draw vertical line: */
+		if (old_screen_y == screen_y)
+			{
+			old_screen_y = screen_y;
+			draw_vertical_lineF = 0;
+			}
+
+		/* Prepare the shift which is required to draw corners; take */
+		/* the next res. if there is no need to draw vertical lines: */
+		if (old_screen_y < screen_y) shift = -1;
+		else shift = +1;
+
+		/* Draw three vertical lines: */
+		if (draw_vertical_lineF)
+			{
+			XDrawLine (guiSP->displaySP,
+				   guiSP->main_hidden_pixmapID,
+				   guiSP->theGCA[1],
+				   screen_x0, old_screen_y - shift,
+				   screen_x0, screen_y - shift);
+			XDrawLine (guiSP->displaySP,
+				   guiSP->main_hidden_pixmapID,
+				   guiSP->theGCA[2],
+				   screen_x0 + 1, old_screen_y,
+				   screen_x0 + 1, screen_y);
+			XDrawLine (guiSP->displaySP,
+				   guiSP->main_hidden_pixmapID,
+				   guiSP->theGCA[3],
+				   screen_x0 + 2, old_screen_y + shift,
+				   screen_x0 + 2, screen_y + shift);
+			}
+
+		/* Copy the y coordinate for later use: */
+		old_screen_y = screen_y;
+
+		/* Fill NearestAtomS array: */
+		for (screen_x  = screen_x0 + 2;
+		     screen_x <= screen_x1 - 1;
+		     screen_x++)
+			{
+			for (screen_y  = screen_y0;
+			     screen_y <= screen_y1;
+			     screen_y++)
+				{
+				/* Prepare index  to the array */
+				/* of NearestAtomS structures: */
+				pixelI = guiSP->main_win_free_area_width *
+					 screen_y + screen_x;
+
+				/* Check the pixel index: */
+				if (pixelI >= pixelsN) continue;
+
+				/* Pointer to  NearestAtomS struct. */
+				/* assigned to current coordinates: */
+				curr_pixelSP = nearest_atomSP + pixelI;
+
+				/* Refresh NearestAtomS associated with */
+				/* this pixel;  residue index is stored */
+				/* to location reserved for atom index. */
+				curr_pixelSP->last_refreshI = refreshI;
+				curr_pixelSP->atomI = residueI;
+				curr_pixelSP->z = function6;
+				}
+			}
+
+		/* Update the counter of visible residues: */
+		visible_residueI++;
+		}
+	}
+
+/*------draw hydrophobicity function F7 (again blue line):-------------------*/
+
+if (runtimeSP->function7F)
+	{
+	/* Prepare three colors for function F7: */
+        /* Prepare three colors for average hydrophobicity: */
+	ParseColor_ (&rgbS, &color1ID, guiSP, "RGB:8888/DDDD/FFFF", "white");
+	ParseColor_ (&rgbS, &color2ID, guiSP, "RGB:0000/8888/FFFF", "white");
+	ParseColor_ (&rgbS, &color3ID, guiSP, "RGB:0000/4444/8888", "black");
+	XSetForeground (guiSP->displaySP, guiSP->theGCA[1], color1ID);
+	XSetForeground (guiSP->displaySP, guiSP->theGCA[2], color2ID);
+	XSetForeground (guiSP->displaySP, guiSP->theGCA[3], color3ID);
+
+	/* Reset the counter of visible residues: */
+	visible_residueI = 0;
+
+	/* Scan the sequence: */
+	for (residueI = 0; residueI < residuesN; residueI++)
+		{
+		/* Check is the residue array index inside the range: */
+		if ((residueI < range_startI) || (residueI > range_endI))
+			{
+			continue;
+			}
+
+		/* Copy the function value: */
+		function7 = (double) *(runtimeSP->function7P + residueI);
+
+		/* Prepare the section index: */
+		sectionI = visible_residueI / residues_per_sectionN;
+
+		/* Prepare the local residue index: */
+		local_residueI = visible_residueI % residues_per_sectionN;
+
+		/* Prepare screen coordinates: */
+		screen_x0 = screen_margin_x +
+			    local_residueI * residue_screen_width -
+			    half_residue_width - 1;
+		screen_x1 = screen_x0 + residue_screen_width + 2;
+		d = (function7 - ordinate_min) * ordinate_scale;
+		screen_y0 = screen_margin_top + sectionI * section_height;
+		screen_y1 = screen_y0 + section_height;
+		screen_y  = screen_y1 - (int) d;
+
+		/* Draw triple line: */
+		XDrawLine (guiSP->displaySP,
+			   guiSP->main_hidden_pixmapID,
+			   guiSP->theGCA[1],
+			   screen_x0, screen_y - 1,
+			   screen_x1, screen_y - 1);
+		XDrawLine (guiSP->displaySP,
+			   guiSP->main_hidden_pixmapID,
+			   guiSP->theGCA[2],
+			   screen_x0, screen_y,
+			   screen_x1, screen_y);
+		XDrawLine (guiSP->displaySP,
+			   guiSP->main_hidden_pixmapID,
+			   guiSP->theGCA[3],
+			   screen_x0, screen_y + 1,
+			   screen_x1, screen_y + 1);
+
+		/* Initialize  the flag  which says is */
+		/* it necessary to draw vertical line: */
+		draw_vertical_lineF = 1;
+
+		/* For  the first residue in  the current */
+		/* section do not draw the vertical line: */
+		if (local_residueI == 0)
+			{
+			old_screen_y = screen_y0;
+			draw_vertical_lineF = 0;
+			}
+
+		/* For the first residue, do not draw the vertical line: */
+		if (residueI == range_startI)
+			{
+			old_screen_y = screen_y;
+			draw_vertical_lineF = 0;
+			}
+
+		/* Check is it necessary to draw vertical line: */
+		if (old_screen_y == screen_y)
+			{
+			old_screen_y = screen_y;
+			draw_vertical_lineF = 0;
+			}
+
+		/* Prepare the shift which is required to draw corners; take */
+		/* the next res. if there is no need to draw vertical lines: */
+		if (old_screen_y < screen_y) shift = -1;
+		else shift = +1;
+
+		/* Draw three vertical lines: */
+		if (draw_vertical_lineF)
+			{
+			XDrawLine (guiSP->displaySP,
+				   guiSP->main_hidden_pixmapID,
+				   guiSP->theGCA[1],
+				   screen_x0, old_screen_y - shift,
+				   screen_x0, screen_y - shift);
+			XDrawLine (guiSP->displaySP,
+				   guiSP->main_hidden_pixmapID,
+				   guiSP->theGCA[2],
+				   screen_x0 + 1, old_screen_y,
+				   screen_x0 + 1, screen_y);
+			XDrawLine (guiSP->displaySP,
+				   guiSP->main_hidden_pixmapID,
+				   guiSP->theGCA[3],
+				   screen_x0 + 2, old_screen_y + shift,
+				   screen_x0 + 2, screen_y + shift);
+			}
+
+		/* Copy the y coordinate for later use: */
+		old_screen_y = screen_y;
+
+		/* Fill NearestAtomS array: */
+		for (screen_x  = screen_x0 + 2;
+		     screen_x <= screen_x1 - 1;
+		     screen_x++)
+			{
+			for (screen_y  = screen_y0;
+			     screen_y <= screen_y1;
+			     screen_y++)
+				{
+				/* Prepare index  to the array */
+				/* of NearestAtomS structures: */
+				pixelI = guiSP->main_win_free_area_width *
+					 screen_y + screen_x;
+
+				/* Check the pixel index: */
+				if (pixelI >= pixelsN) continue;
+
+				/* Pointer to  NearestAtomS struct. */
+				/* assigned to current coordinates: */
+				curr_pixelSP = nearest_atomSP + pixelI;
+
+				/* Refresh NearestAtomS associated with */
+				/* this pixel;  residue index is stored */
+				/* to location reserved for atom index. */
+				curr_pixelSP->last_refreshI = refreshI;
+				curr_pixelSP->atomI = residueI;
+				curr_pixelSP->z = function7;
+				}
+			}
+
+		/* Update the counter of visible residues: */
+		visible_residueI++;
+		}
+	}
+
 /*------copy the prepared image to the main window:--------------------------*/
 
 /* Copy hidden pixmap to the main window: */
