@@ -240,7 +240,7 @@ for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 /* Add symbol for trans residues to the legend: */
 
 /* Position of symbol center: */
-screen_phi = frame_screen_x0 + (frame_screen_x1 - frame_screen_x0) / 4;
+screen_phi = frame_screen_x0;
 screen_psi = frame_screen_y1 + guiSP->main_winS.text_line_height -
 	     guiSP->main_winS.text_line_height / 5 - 5;
 
@@ -374,7 +374,7 @@ for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 /* Add symbol for cis residues to the legend: */
 
 /* Position of symbol center: */
-screen_phi = frame_screen_x0 + (frame_screen_x1 - frame_screen_x0) / 2;
+screen_phi = frame_screen_x0 + (frame_screen_x1 - frame_screen_x0) / 4;
 screen_psi = frame_screen_y1 + guiSP->main_winS.text_line_height -
 	     guiSP->main_winS.text_line_height / 5 - 5;
 
@@ -508,7 +508,7 @@ for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 /* Add symbol for bad residues to the legend: */
 
 /* Position of symbol center: */
-screen_phi = frame_screen_x0 + 3 * (frame_screen_x1 - frame_screen_x0) / 4;
+screen_phi = frame_screen_x0 + 2 * (frame_screen_x1 - frame_screen_x0) / 4;
 screen_psi = frame_screen_y1 + guiSP->main_winS.text_line_height -
 	     guiSP->main_winS.text_line_height / 5 - 5;
 
