@@ -1,4 +1,4 @@
-/* Copyright (C) 2000 Damir Zucic */
+/* Copyright (C) 2000-2004 Damir Zucic */
 
 /*=============================================================================
 
@@ -63,7 +63,7 @@ int		max_length;
 size_t		residuesN, residueI;
 char		*residue_nameP;
 char		residue_nameA[RESNAMESIZE];
-int		serialI, range_startI, range_endI, residues_in_vennN = 0;
+int		range_startI, range_endI, residues_in_vennN = 0;
 size_t		vennI = 0;
 int		alaN = 0, argN = 0, asnN = 0, aspN = 0, cysN = 0;
 int		glnN = 0, gluN = 0, glyN = 0, hisN = 0, ileN = 0;
@@ -94,16 +94,18 @@ if (residuesN == 0)
 /* The maximal residue name length: */
 max_length = RESNAMESIZE - 1;
 
-/* Residue serial range: */
+/* Residue array index range: */
 range_startI = runtimeSP->range_startI;
 range_endI   = runtimeSP->range_endI;
 
 /* Count the number of residues in the specified range: */
 for (residueI = 0; residueI < residuesN; residueI++)
 	{
-	/* Check is the residue serial index inside the range: */
-	serialI = *(runtimeSP->serialIP + residueI);
-	if ((serialI < range_startI) || (serialI > range_endI)) continue;
+	/* Check is the residue array index inside the range: */
+	if (((int) residueI < range_startI) || ((int) residueI > range_endI))
+		{
+		continue;
+		}
 
 	/* Increase the count of residues if current */
 	/* residue  belongs to  the specified range: */
@@ -145,9 +147,11 @@ if (screen_delta_y < 0) screen_delta_y = 0;
 /* Count residues by type: */
 for (residueI = 0; residueI < residuesN; residueI++)
 	{
-	/* Check is the residue serial index inside the range: */
-	serialI = *(runtimeSP->serialIP + residueI);
-	if ((serialI < range_startI) || (serialI > range_endI)) continue;
+	/* Check is the residue array index inside the range: */
+	if (((int) residueI < range_startI) || ((int) residueI > range_endI))
+		{
+		continue;
+		}
 
 	/* Pointer to the current residue name: */
 	residue_nameP = runtimeSP->sequenceP + residueI * max_length;
@@ -192,8 +196,9 @@ for (residueI = 0; residueI < residuesN; residueI++)
 	}
 
 /* Prepare the combined counts: */
-hydrophobicN = pheN + tyrN + trpN + hisN + lysN + metN +
-	       ileN + leuN + valN + alaN + glyN + cysN;
+hydrophobicN = pheN + tyrN + trpN + hisN + metN +
+	       ileN + leuN + valN + alaN + glyN +
+	       cysN;
 polarN = tyrN + trpN + hisN + lysN + argN + gluN +
 	 glnN + aspN + asnN + thrN + serN + S_H_cysN;
 smallN = glyN + alaN + serN + proN + valN + thrN + aspN + asnN + cysN;
@@ -607,7 +612,19 @@ XDrawString (guiSP->displaySP,
 sprintf (stringA, "ARG: %d", argN);
 text_width = XTextWidth (guiSP->main_winS.fontSP, stringA, strlen (stringA));
 screen_x0 = screen_x - text_width / 2;
-d = 0.345 * (double) screen_delta_y;
+d = 0.340 * (double) screen_delta_y;
+screen_y0 = screen_margin_y + (int) d + text_height / 2;
+XDrawString (guiSP->displaySP,
+	     guiSP->main_hidden_pixmapID,
+	     guiSP->theGCA[0],
+	     screen_x0, screen_y0,
+	     stringA, strlen (stringA));
+
+/* LYS: */
+sprintf (stringA, "LYS: %d", lysN);
+text_width = XTextWidth (guiSP->main_winS.fontSP, stringA, strlen (stringA));
+screen_x0 = screen_x - text_width / 2;
+d = 0.380 * (double) screen_delta_y;
 screen_y0 = screen_margin_y + (int) d + text_height / 2;
 XDrawString (guiSP->displaySP,
 	     guiSP->main_hidden_pixmapID,
@@ -695,18 +712,6 @@ XDrawString (guiSP->displaySP,
 	     screen_x0, screen_y0,
 	     stringA, strlen (stringA));
 
-/* LYS: */
-sprintf (stringA, "LYS: %d", lysN);
-text_width = XTextWidth (guiSP->main_winS.fontSP, stringA, strlen (stringA));
-screen_x0 = screen_x - text_width / 2;
-d = 0.375 * (double) screen_delta_y;
-screen_y0 = screen_margin_y + (int) d + text_height / 2;
-XDrawString (guiSP->displaySP,
-	     guiSP->main_hidden_pixmapID,
-	     guiSP->theGCA[0],
-	     screen_x0, screen_y0,
-	     stringA, strlen (stringA));
-
 /* CYS (S-S): */
 sprintf (stringA, "CYS (S-S): %d", S_S_cysN);
 text_width = XTextWidth (guiSP->main_winS.fontSP, stringA, strlen (stringA));
