@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2002 Damir Zucic */
+/* Copyright (C) 2000-2003 Damir Zucic */
 
 /*=============================================================================
 
@@ -271,7 +271,8 @@ switch (eventS.type)
 
 		client_eventSP = (XClientMessageEvent *) &eventS;
 		if ((client_eventSP->message_type == guiSP->protocols_atom) &&
-	   	 (client_eventSP->data.l[0] == guiSP->delete_window_atom))
+	   	 (client_eventSP->data.l[0] ==
+					(long) guiSP->delete_window_atom))
 			{
 			return 1;
 			}
