@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2002 Damir Zucic */
+/* Copyright (C) 2000-2004 Damir Zucic */
 
 /*=============================================================================
 
@@ -49,7 +49,7 @@ int Exclude_ (SelectS *exclude_selectSP, char *stringP)
 {
 char		string_copyA[STRINGSIZE];
 char		*remainderP;
-char		tokenA[SHORTSTRINGSIZE];
+char		tokenA[STRINGSIZE];
 char		*exceptP, *dataP;
 
 /* Copy the input string to preserve it: */
@@ -61,7 +61,7 @@ string_copyA[STRINGSIZE - 1] = '\0';
 remainderP = stringP;
 
 /* The first token should contain chain identifiers: */
-remainderP = ExtractToken_ (tokenA, SHORTSTRINGSIZE, remainderP, "/");
+remainderP = ExtractToken_ (tokenA, STRINGSIZE, remainderP, "/");
 if (remainderP == NULL) return -1;
 
 /* If keyword exc is present, skip one token and extract chain identifiers: */
@@ -85,7 +85,7 @@ else
 	}
 
 /* The second token should contain residue ranges: */
-remainderP = ExtractToken_ (tokenA, SHORTSTRINGSIZE, remainderP, "/");
+remainderP = ExtractToken_ (tokenA, STRINGSIZE, remainderP, "/");
 if (remainderP == NULL) return -4;
 
 /* If keyword exc is present, skip one token and extract residue ranges: */
@@ -109,7 +109,7 @@ else
 	}
 
 /* The third token should contain residue names: */ 
-remainderP = ExtractToken_ (tokenA, SHORTSTRINGSIZE, remainderP, "/");
+remainderP = ExtractToken_ (tokenA, STRINGSIZE, remainderP, "/");
 if (remainderP == NULL) return -7;
 
 /* If keyword exc is present, skip one token and extract residue names: */
@@ -133,7 +133,7 @@ else
 	}
 
 /* The fourth (the last) token should contain atom names: */ 
-remainderP = ExtractToken_ (tokenA, SHORTSTRINGSIZE, remainderP, "/");
+remainderP = ExtractToken_ (tokenA, STRINGSIZE, remainderP, "/");
 if (remainderP == NULL) return -10;
 
 /* If keyword exc is present, skip one token and extract atom names: */
