@@ -241,6 +241,7 @@ int		Blur_ (MolComplexS *, int,
 int		Group_ (MolComplexS *, int,
 			RuntimeS *, ConfigS *, GUIS *,
 			NearestAtomS *, size_t, unsigned int *, char *);
+int		Dump_ (MolComplexS *, int, RuntimeS *, char *);
 
 /*======execute command (1):=================================================*/
 
@@ -910,6 +911,13 @@ else if (strstr (tokenA, "GRO") == tokenA)
 		       remainderP);
 	}
 
+/*------dump:----------------------------------------------------------------*/
+
+else if (strstr (tokenA, "DUM") == tokenA)
+	{
+	return Dump_ (mol_complexSP, *mol_complexesNP, runtimeSP, remainderP);
+	}
+
 /*------execute:-------------------------------------------------------------*/
 
 else if (strstr (tokenA, "EXE") == tokenA)
