@@ -239,6 +239,7 @@ int		Blur_ (MolComplexS *, int,
 int		Group_ (MolComplexS *, int,
 			RuntimeS *, ConfigS *, GUIS *,
 			NearestAtomS *, size_t, unsigned int *, char *);
+int		Dump_ (MolComplexS *, int, RuntimeS *, char *);
 
 /*======execute command (2):=================================================*/
 
@@ -886,6 +887,13 @@ else if (strstr (tokenA, "GRO") == tokenA)
 		       remainderP);
 	}
 
+/*------dump:----------------------------------------------------------------*/
+
+else if (strstr (tokenA, "DUM") == tokenA)
+	{
+	return Dump_ (mol_complexSP, *mol_complexesNP, runtimeSP, remainderP);
+	}
+
 /*------end of command recognition section.----------------------------------*/
 
 /* If this point is reached, the command was not recognized! */
