@@ -1,4 +1,4 @@
-/* Copyright (C) 2000 Damir Zucic */
+/* Copyright (C) 2000-2002 Damir Zucic */
 
 /*=============================================================================
 
@@ -218,7 +218,7 @@ while ((j = i++) < argc)
 			}
 
 		/*** Copy the value: ***/
-		configSP->default_atom_styleI = (short int) n;
+		configSP->default_atom_styleI = n;
 
 		/*** Update index and number of arguments: ***/
 		i++;
@@ -251,7 +251,7 @@ while ((j = i++) < argc)
 			}
 
 		/*** Copy the value: ***/
-		configSP->default_bond_styleI = (short int) n;
+		configSP->default_bond_styleI = n;
 
 		/*** Update index and number of arguments: ***/
 		i++;
@@ -306,7 +306,7 @@ while ((j = i++) < argc)
                 n = ExtractInteger_ (argv[i]);
 
                 /*** Check it: ***/
-                if ((n <= 0) || (n > MAXSURFACES))
+                if ((n <= 0) || (n > MAXCOLORSURFACES))
                         {
                         ErrorMessage_ ("garlic", "ExtractArgs_", "",
                                        "Bad number of fading surfaces!\n",
@@ -315,7 +315,7 @@ while ((j = i++) < argc)
                         }
 
                 /*** Copy the value: ***/
-                configSP->default_surfacesN = (short int) n;
+                configSP->default_surfacesN = n;
 
                 /*** Update index and number of arguments: ***/
                 i++;
@@ -338,7 +338,7 @@ while ((j = i++) < argc)
                 /*** Extract and check  the surface index: ***/
                 /*** (Note that leading minus is skipped!) ***/
                 surfaceI = ExtractIndex_ (argv[j] + 1);
-                if ((surfaceI < 0) || (surfaceI >= MAXSURFACES))
+                if ((surfaceI < 0) || (surfaceI >= MAXCOLORSURFACES))
                         {
                         ErrorMessage_ ("garlic", "ExtractArgs_", "",
                                        "Bad fading surface index!\n",
@@ -372,7 +372,7 @@ while ((j = i++) < argc)
                 /*** Extract and check  the surface index: ***/
                 /*** (Note that leading minus is skipped!) ***/
                 surfaceI = ExtractIndex_ (argv[j] + 1);
-                if ((surfaceI < 0) || (surfaceI >= MAXSURFACES))
+                if ((surfaceI < 0) || (surfaceI >= MAXCOLORSURFACES))
                         {
                         ErrorMessage_ ("garlic", "ExtractArgs_", "",
                                        "Bad fading surface index!\n",
@@ -406,7 +406,7 @@ while ((j = i++) < argc)
                 /*** Extract and check  the surface index: ***/
                 /*** (Note that leading minus is skipped!) ***/
                 surfaceI = ExtractIndex_ (argv[j] + 1);
-                if ((surfaceI < 0) || (surfaceI >= MAXSURFACES))
+                if ((surfaceI < 0) || (surfaceI >= MAXCOLORSURFACES))
                         {
                         ErrorMessage_ ("garlic", "ExtractArgs_", "",
                                        "Bad fading surface index!\n",
