@@ -48,7 +48,8 @@ if (guiSP->control_winS.pixmapF) XFreePixmap (guiSP->displaySP,
 					      guiSP->control_winS.pixmapID);
 if (guiSP->main_hidden_pixmapF)	 XFreePixmap (guiSP->displaySP,
 					      guiSP->main_hidden_pixmapID);
-
+if (guiSP->small_arrows_pixmapF) XFreePixmap (guiSP->displaySP,
+					      guiSP->small_arrows_pixmapID);
 /* Free cursors: */
 if (guiSP->main_winS.cursorF)	 XFreeCursor (guiSP->displaySP,
 					      guiSP->main_winS.cursorID);
