@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2004 Damir Zucic */
+/* Copyright (C) 2000-2006 Damir Zucic */
 
 /*=============================================================================
 
@@ -49,6 +49,8 @@ if (runtimeSP->hydrophobicityP)		free (runtimeSP->hydrophobicityP);
 
 if (runtimeSP->average_hydrophobicityP)
 				free (runtimeSP->average_hydrophobicityP);
+if (runtimeSP->weighted_hydrophobicityP)
+				free (runtimeSP->weighted_hydrophobicityP);
 if (runtimeSP->hydrophobic_momentP)
 				free (runtimeSP->hydrophobic_momentP);
 if (runtimeSP->larger_sided_hyphobP)
@@ -61,6 +63,8 @@ if (runtimeSP->function2P)		free (runtimeSP->function2P);
 if (runtimeSP->function3P)		free (runtimeSP->function3P);
 if (runtimeSP->function4P)		free (runtimeSP->function4P);
 if (runtimeSP->function5P)		free (runtimeSP->function5P);
+if (runtimeSP->function6P)		free (runtimeSP->function6P);
+if (runtimeSP->function7P)		free (runtimeSP->function7P);
 
 if (runtimeSP->auxiliaryIP)		free (runtimeSP->auxiliaryIP);
 if (runtimeSP->aux_doubleP)		free (runtimeSP->aux_doubleP);
