@@ -525,13 +525,17 @@ for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 	    /*@@*/ /* TEMPORARY CHANGES: */
 	    if (r12 > max_dist) continue; /*@@*/
 
-#ifdef ALLDONE /*@@*/
+#ifdef PLAYING_WITH_HYBONDS /*@@*/
 	    /*@@*/ /* CREATE DUMMY ATOMS: */
 	    printf ("ATOM%7ld  J   JEL%6ld    %8.3f%8.3f%8.3f  1.00 10.00\n",
 		    hydrogen_bondsN + 100, hydrogen_bondsN + 100,
-		    10 * cos_theta1,
-		    10 * cos_theta2,
-		    10 * r12);
+		    10.0 * r12,
+		    10.0 * cos_theta1,
+		    10.0 * cos_theta2);
+#endif /*@@*/
+
+#ifdef PLAYING_WITH_HYBONDS /*@@*/
+	    printf ("%8.3f%8.3f%8.3f\n", r12, cos_theta1, cos_theta2); /*@@*/
 #endif /*@@*/
 	    }
 	}
