@@ -1,4 +1,4 @@
-/* Copyright (C) 2003 Damir Zucic */
+/* Copyright (C) 2003-2006 Damir Zucic */
 
 /*=============================================================================
 
@@ -7,17 +7,19 @@
 Purpose:
 	Execute group command:  catch a set of macromolecular complexes,
 	releasing some others. A single rotation center will be prepared
-	for the entire group.  All atoms,  including the atoms which are
-	not selected,  will be taken into account.  To break  the group,
-	use the command CATCH.  At least one,  but typically two or more
-	complex identifiers  should be  specified  as command arguments.
-	The keyword SAVE may be used to save the whole group, where each
-	structure will be treated as a single chain. The keyword SSC may
-	be used to save the structure as  a single chain,  with no chain
-	identifier.  If some structure from  the group consist of two or
-	more chains,  in both cases  the original chain identifiers will
-	be lost.  The keyword  ALL  may be used  to group  all available
-	(loaded) structures.
+	for the entire group,  except if grouping was done using keyword
+	ALL.  In that case, each macromolecular center will have its own
+	rotation center  (the old one).  All atoms,  including the atoms
+	which are not selected, will be taken into account. To break the
+	group, use the command CATCH.  If keyword ALL is not used,  then
+	two or more  complex identifiers  should be specified as command
+	arguments. The keyword SAVE may be used to save the whole group,
+	where  each structure  will be treated  as  a single chain.  The
+	keyword SSC may be used to save the structure as a single chain,
+	with  no chain  identifier.  If any structure consist  of two or
+	more chains,  the original chain identifiers  will be lost.  The
+	keyword  ALL  may be used to group all loaded structures,  where
+	each of these structures will retain its own rotation center.
 
 Input:
 	(1) Pointer to MolComplexS structure,  with macromol. complexes.
@@ -395,6 +397,8 @@ else if (strstr (tokenA, "ALL") == tokenA)
 		curr_mol_complexSP->group_memberF = 1;
 		}
 
+	/* Each macromolecular complex retains its own rotation center! */
+
 	/* Return to the caller, redrawing is not required: */
 	return COMMAND_GROUP;
 	}
