@@ -1,4 +1,4 @@
-/* Copyright (C) 2004-2006 Damir Zucic */
+/* Copyright (C) 2006 Damir Zucic */
 
 /*=============================================================================
 
@@ -33,8 +33,6 @@ Notes:
 
 #include <stdio.h>
 
-#include <math.h>
-
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/Xos.h>
@@ -49,84 +47,73 @@ int HyphobFunction1_ (double *min_functionP, double *max_functionP,
 		      RuntimeS *runtimeSP)
 {
 int             residuesN, residueI;   /* Do not use size_t instead of int ! */
+int		max_length;
+int		count;
 int		windowI, combinedI;
-int		used_residuesN;
+char		*residue_nameP;
+char		residue_nameA[RESNAMESIZE];
 double		function_value;
-double		hydrophobicity;
-static double	weightA[11]  = { 1.0,  1.0,  1.0,  1.0,  1.0,
-				 0.0,
-				-1.0, -1.0, -1.0, -1.0, -1.0};
 
 /*------prepare some parameters:---------------------------------------------*/
 
-/* The number of residues in sequence buffer: */
+/* The number of residues in the sequence buffer: */
 residuesN = (int) runtimeSP->residuesN;
 if (residuesN == 0) return -1;
 
+/* The maximal residue name length: */
+max_length = RESNAMESIZE - 1;
+
 /*------calculate the function F1:-------------------------------------------*/
 
 /* Initialize the extreme values: */
 *min_functionP = +999999.0;
 *max_functionP = -999999.0;
 
-/* 20041104.1615: */
-/*--------------------------------------------------*/
-/* A window of 11 residues is scanned. The weighted */
-/* total  hydrophobicity  is calculated and stored. */
-/* Inspired by  the hydrophobic hexapeptide  model. */
-/* The following hyphobicity patterns are searched: */
-/*--------------------------------------------------*/
-/* five_hydrophobic - five_hydrophilic              */
-/* five_hydrophilic - five_hydrophobic              */
-/*--------------------------------------------------*/
+/* 20060612.1446: */
+/* Scan the window of 5 residues. Count ASP, ASN, GLU, GLN, ARG, LYS, HIS. */
 
-/* Initialize (reset) the function value: */
+/* Scan the sequence: */
 for (residueI = 0; residueI < residuesN; residueI++)
 	{
 	/* Reset the function value, it might be initialized before: */
 	*(runtimeSP->function1P + residueI) = 0.0;
-	}
 
-/* Scan the sequence, ignoring 5 residues at each end: */
-for (residueI = 5; residueI < residuesN - 5; residueI++)
-	{
-	/* Reset the number of residues used to prepare the raw values: */
-	used_residuesN = 0;
-
-	/* Reset the local variable which is used for the function value: */
-	function_value = 0.0;
+	/* Reset the counter: */
+	count = 0;
 
 	/* Scan the sliding window: */
-	for (windowI = 0; windowI < 11; windowI++)
+	for (windowI = -2; windowI <= 2; windowI++)
 		{
 		/* Prepare and check the combined index: */
-		combinedI = residueI + windowI - 5;
+		combinedI = residueI + windowI;
 		if (combinedI < 0) continue;
 		if (combinedI >= residuesN) continue;
 
-		/* Prepare the hydrophobicity value: */
-		hydrophobicity = *(runtimeSP->hydrophobicityP + combinedI);
+		/* Pointer  to  the residue  name of */
+		/* the residue defined by combinedI: */
+		residue_nameP = runtimeSP->sequenceP + combinedI * max_length;
 
-		/* Update the function value: */
-		function_value += weightA[windowI] * hydrophobicity;
+		/* Copy the residue name: */
+		strncpy (residue_nameA, residue_nameP, max_length);
+		residue_nameA[max_length] = '\0';
 
-		/* Update the number of used residues: */
-		used_residuesN++;
+		/* Add +1 for charged and zwitterionic residues: */
+		if ((strcmp (residue_nameA, "ASP") == 0) ||
+		    (strcmp (residue_nameA, "ASN") == 0) ||
+		    (strcmp (residue_nameA, "GLU") == 0) ||
+		    (strcmp (residue_nameA, "GLN") == 0) ||
+		    (strcmp (residue_nameA, "ARG") == 0) ||
+		    (strcmp (residue_nameA, "LYS") == 0) ||
+		    (strcmp (residue_nameA, "HIS") == 0))
+			{
+			count++;
+			}
 		}
 
-	/* Check the number of used residues: */
-	if (used_residuesN == 0) continue;
-
-	/* Scale the function value (it should fit */
-	/* to the same plot with other functions): */
-	function_value /= 10.0;
-
 	/* Store the function value: */
+	function_value = (double) count;
 	*(runtimeSP->function1P + residueI) = function_value;
 
-	/* Dummy values should not be used to determine extreme values: */
-	if (used_residuesN < 10) continue;
-
 	/* Find the extreme values: */
 	if (function_value < *min_functionP) *min_functionP = function_value;
 	if (function_value > *max_functionP) *max_functionP = function_value;
