@@ -1,4 +1,4 @@
-/* Copyright (C) 2004-2006 Damir Zucic */
+/* Copyright (C) 2006 Damir Zucic */
 
 /*=============================================================================
 
@@ -48,61 +48,45 @@ int HyphobFunction4_ (double *min_functionP, double *max_functionP,
 {
 int             residuesN, residueI;   /* Do not use size_t instead of int ! */
 int		max_length;
-int		window_width = 7;
-int		half_window_width;
+int		count;
 int		windowI, combinedI;
-int		used_residuesN;
 char		*residue_nameP;
 char		residue_nameA[RESNAMESIZE];
-int		residue_from_setF;
 double		function_value;
 
 /*------prepare some parameters:---------------------------------------------*/
 
-/* The number of residues in sequence buffer: */
+/* The number of residues in the sequence buffer: */
 residuesN = (int) runtimeSP->residuesN;
 if (residuesN == 0) return -1;
 
 /* The maximal residue name length: */
 max_length = RESNAMESIZE - 1;
 
-/* Half of the window width: */
-half_window_width = window_width / 2;
-
 /*------calculate the function F4:-------------------------------------------*/
 
 /* Initialize the extreme values: */
 *min_functionP = +999999.0;
 *max_functionP = -999999.0;
 
-/* 20040927.1536: */
-/* A window of window_width residues is scanned. The total number of very */
-/* polar residues  (ASP, GLU, ASN, GLN, ARG, LYS, but no HIS) is counted. */
-
-/* Initialize (reset) the function value: */
-for (residueI = 0; residueI < residuesN; residueI++)
-	{
-	/* Reset the function value, it might be initialized before: */
-	*(runtimeSP->function4P + residueI) = 0.0;
-	}
+/* 20060608.1158: */
+/* Scan the window of 7 residues.  Count */
+/* LEU, ILE, VAL, ALA, MET, PHE and TYR. */
 
 /* Scan the sequence: */
 for (residueI = 0; residueI < residuesN; residueI++)
 	{
-	/* Reset the counts of residues used to prepare the raw values: */
-	used_residuesN = 0;
-
 	/* Reset the function value, it might be initialized before: */
 	*(runtimeSP->function4P + residueI) = 0.0;
 
-	/* Reset the local variable reserved for the function value: */
-	function_value = 0.0;
+	/* Reset the counter: */
+	count = 0;
 
 	/* Scan the sliding window: */
-	for (windowI = 0; windowI < window_width; windowI++)
+	for (windowI = -3; windowI <= 3; windowI++)
 		{
 		/* Prepare and check the combined index: */
-		combinedI = residueI + windowI - half_window_width;
+		combinedI = residueI + windowI;
 		if (combinedI < 0) continue;
 		if (combinedI >= residuesN) continue;
 
@@ -114,47 +98,23 @@ for (residueI = 0; residueI < residuesN; residueI++)
 		strncpy (residue_nameA, residue_nameP, max_length);
 		residue_nameA[max_length] = '\0';
 
-		/* Now check the residue name. */
-
-		/* Initial assumption: residue belongs to the specified set: */
-		residue_from_setF = 1;
-
-		/* Formal, single pass loop: */
-		do
+		/* Add +1 for selected hydrophobic residues: */
+		if ((strcmp (residue_nameA, "LEU") == 0) ||
+		    (strcmp (residue_nameA, "ILE") == 0) ||
+		    (strcmp (residue_nameA, "VAL") == 0) ||
+		    (strcmp (residue_nameA, "MET") == 0) ||
+		    (strcmp (residue_nameA, "ALA") == 0) ||
+		    (strcmp (residue_nameA, "PHE") == 0) ||
+		    (strcmp (residue_nameA, "TYR") == 0))
 			{
-			/* Check the residue name: */
-			if      (strcmp (residue_nameA, "ASP") == 0) break;
-			else if (strcmp (residue_nameA, "GLU") == 0) break;
-			else if (strcmp (residue_nameA, "ASN") == 0) break;
-			else if (strcmp (residue_nameA, "GLN") == 0) break;
-			else if (strcmp (residue_nameA, "ARG") == 0) break;
-			else if (strcmp (residue_nameA, "LYS") == 0) break;
-
-			/* If this point is reached, this residue */
-			/* does not belong  to the specified set. */
-			residue_from_setF = 0;
-
-			/* End of single pass loop: */
-			} while (0);
-
-		/* If  this residue belongs to  the specified */
-		/* set, increment the function value for one: */
-		if (residue_from_setF) function_value += 1.0;
-
-		/* Update the number of used residues: */
-		used_residuesN++;
+			count++;
+			}
 		}
 
-	/* Reduce the function value (arbitrary scaling): */
-	if (function_value < 4) function_value = 0.0; /*@@*/
-	function_value /= 4.0; /*@@*/
-
-	/* Store the function value: */
+	/* Scale and store the function value: */
+	function_value = 1.0 * (double) count;
 	*(runtimeSP->function4P + residueI) = function_value;
 
-        /* Dummy values should not be used to determine extreme values: */
-        if (used_residuesN < window_width) continue;
-
 	/* Find the extreme values: */
 	if (function_value < *min_functionP) *min_functionP = function_value;
 	if (function_value > *max_functionP) *max_functionP = function_value;
