@@ -1,4 +1,4 @@
-/* Copyright (C) 2004-2006 Damir Zucic */
+/* Copyright (C) 2006 Damir Zucic */
 
 /*=============================================================================
 
@@ -33,6 +33,8 @@ Notes:
 
 #include <stdio.h>
 
+#include <math.h>
+
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
 #include <X11/Xos.h>
@@ -44,35 +46,38 @@ Notes:
 /*======function prototypes:=================================================*/
 
 int		HyphobFunction1_ (double *, double *, RuntimeS *);
-int		HyphobFunction4_ (double *, double *, RuntimeS *);
+int		HyphobFunction2_ (double *, double *, RuntimeS *);
 int		HyphobFunction3_ (double *, double *, RuntimeS *);
+int		HyphobFunction4_ (double *, double *, RuntimeS *);
 void		InitHyphob_ (RuntimeS *);
 
 /*======calculate the hydrophobicity function F5:============================*/
 
 int HyphobFunction5_ (double *f5minP, double *f5maxP, RuntimeS *runtimeSP)
 {
-int             residuesN, residueI;   /* Do not use size_t instead of int ! */
+int		residuesN, residueI;   /* Do not use size_t instead of int ! */
 int		max_length;
-int		old_scaleI;
-double		f1, f1min, f1max;
+char		*residue_nameP;
+char		residue_nameA[RESNAMESIZE];
+double		f1, f1min, f1max, f1before;
+double		f2, f2min, f2max, f2before;
+double		f3, f3min, f3max, f3before;
 double		f4, f4min, f4max;
 double		f5;
+int		windowI, combinedI;
+double		left_value, central_value, right_value;
+double		weightA[5] = {1.00, 1.00, 1.00, 1.00, 1.00};
+double		average_value;
 
 /*------prepare some parameters:---------------------------------------------*/
 
-/* The number of residues in sequence buffer: */
+/* The number of residues in the sequence buffer: */
 residuesN = (int) runtimeSP->residuesN;
 if (residuesN == 0) return -1;
 
 /* The maximal residue name length: */
 max_length = RESNAMESIZE - 1;
 
-/*------copy the old scale index:--------------------------------------------*/
-
-/* Copy the old hydrophobicity scale index: */
-old_scaleI = runtimeSP->hydrophobicity_scaleI;
-
 /*------initialize (reset) F5:-----------------------------------------------*/
 
 /* Initialize F5: */
@@ -84,54 +89,54 @@ for (residueI = 0; residueI < residuesN; residueI++)
 
 /*------calculate the function F1:-------------------------------------------*/
 
-/* Use the octanol scale: */
-runtimeSP->hydrophobicity_scaleI = 0;
-
-/* Update the hydrophobicity values in the sequence buffer: */
-InitHyphob_ (runtimeSP);
-
 /* Calculate the function F1: */
 HyphobFunction1_ (&f1min, &f1max, runtimeSP);
 
+/*------calculate the function F2:-------------------------------------------*/
+
+/* Calculate the function F2: */
+HyphobFunction2_ (&f2min, &f2max, runtimeSP);
+
+/*------calculate the function F3:-------------------------------------------*/
+
+/* Calculate the function F3: */
+HyphobFunction3_ (&f3min, &f3max, runtimeSP);
+
 /*------calculate the function F4:-------------------------------------------*/
 
-/* Use the octanol scale: */
-runtimeSP->hydrophobicity_scaleI = 0;
-
-/* Update the hydrophobicity values in the sequence buffer: */
-InitHyphob_ (runtimeSP);
-
-/* Calculate the function F4: */
+/* Calculate the function F4: */ 
 HyphobFunction4_ (&f4min, &f4max, runtimeSP);
 
-/*------restore the old hydrophobicity scale index:--------------------------*/
-
-/* Restore the scale index: */
-runtimeSP->hydrophobicity_scaleI = old_scaleI;
-
-/* Update the hydrophobicity values in the sequence buffer: */ 
-InitHyphob_ (runtimeSP);
-
 /*------calculate the function F5:-------------------------------------------*/
 
 /* Initialize the extreme values: */
 *f5minP = +999999.0;
 *f5maxP = -999999.0;
 
-/* 20040920.1447: */
-/* The function F5 is calculated from F1 and F4. */
-
 /* Scan the sequence and calculate F5: */
 for (residueI = 0; residueI < residuesN; residueI++)
 	{
-	/* Calculate F5: */
-        f1 = *(runtimeSP->function1P + residueI);
-        f4 = *(runtimeSP->function4P + residueI);
-	f5 = ((f1 - f1min) / (f1max - f1min)) *
-	     ((f4 - f4min) / (f4max - f4min));
+	/* Prepare the pointer to the residue name: */
+	residue_nameP = runtimeSP->sequenceP + residueI * max_length;
 
-	/* Store F5: */
-	*(runtimeSP->function5P + residueI) = f5;
+	/* Copy the residue name: */
+	strncpy (residue_nameA, residue_nameP, max_length);
+	residue_nameA[max_length] = '\0';
+
+	/* Initialize the function value: */
+	*(runtimeSP->function5P + residueI) = 0.0;
+
+	/* Reset default F5 value: */
+	f5 = 0.0;
+
+	/* 20060608.1205: */
+	/* Copy and use F1 and F3. */
+	f1 = *(runtimeSP->function1P + residueI);
+	f3 = *(runtimeSP->function4P + residueI);
+	f5 = f3 - f1;
+
+	/* Scale and store the function value: */
+	*(runtimeSP->function5P + residueI) = 1.0 * f5;
 	}
 
 /*------find the extreme values of F5:---------------------------------------*/
