@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2002 Damir Zucic */
+/* Copyright (C) 2000-2003 Damir Zucic */
 
 /*=============================================================================
 
@@ -415,6 +415,26 @@ memcpy ((color_schemeSP + 22)->middle_rgbSA + 1, &rgbS, rgb_struct_size);
 ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:2222/1111/0000", "white");
 memcpy ((color_schemeSP + 22)->right_rgbSA  + 1, &rgbS, rgb_struct_size);
 
+/*------SKIN (23):-----------------------------------------------------------*/
+
+(color_schemeSP + 23)->surfacesN = 2;
+
+/* Surface 0: */
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:EDED/C5C5/9494", "white");
+memcpy ((color_schemeSP + 23)->left_rgbSA, &rgbS, rgb_struct_size);
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:BCBC/8585/5C5C", "white");
+memcpy ((color_schemeSP + 23)->middle_rgbSA, &rgbS, rgb_struct_size);
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:8A8A/5757/3A3A", "white");
+memcpy ((color_schemeSP + 23)->right_rgbSA, &rgbS, rgb_struct_size);
+
+/* Surface 1: */
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:8585/5555/3535", "white");
+memcpy ((color_schemeSP + 23)->left_rgbSA   + 1, &rgbS, rgb_struct_size);
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:6565/4040/3030", "white");
+memcpy ((color_schemeSP + 23)->middle_rgbSA + 1, &rgbS, rgb_struct_size);
+ParseColor_ (&rgbS, &dummyID, guiSP, "RGB:2D2D/1F1F/1C1C", "white");
+memcpy ((color_schemeSP + 23)->right_rgbSA  + 1, &rgbS, rgb_struct_size);
+
 /*---------------------------------------------------------------------------*/
 
 /* Return positive value on success: */
