@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2002 Damir Zucic */
+/* Copyright (C) 2000-2003 Damir Zucic */
 
 /*=============================================================================
 
@@ -17,6 +17,9 @@ Output:
 Return value:
 	No return value.
 
+Notes:
+	(1) Check init_runtime.c for default hydrophobicity scale!
+
 ========includes:============================================================*/
 
 #include <stdio.h>
