@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2005 Damir Zucic */
+/* Copyright (C) 2000-2006 Damir Zucic */
 
 /*=============================================================================
 
@@ -268,6 +268,18 @@ if (runtimeSP->average_hydrophobicityP == NULL)
 	return -10;
 	}
 
+/* Allocate memory for weighted hydrophobicity: */
+elementsN = MAXRESIDUES;
+runtimeSP->weighted_hydrophobicityP =
+				(double *) calloc (elementsN, double_size);
+if (runtimeSP->weighted_hydrophobicityP == NULL)
+	{
+	ErrorMessage_ ("garlic", "InitRuntime_", "",
+		"Failed to allocate memory for weighted hydrophobicity!\n",
+		"", "", "");
+	return -11;
+	}
+
 /* Allocate memory for hydrophobic moment: */
 elementsN = MAXRESIDUES;
 runtimeSP->hydrophobic_momentP = (double *) calloc (elementsN, double_size);
@@ -276,7 +288,7 @@ if (runtimeSP->hydrophobic_momentP == NULL)
 	ErrorMessage_ ("garlic", "InitRuntime_", "",
 		"Failed to allocate memory for hydrophobic moment!\n",
 		"", "", "");
-	return -11;
+	return -12;
 	}
 
 /* Allocate memory for sided hydrophobicity (two buffers): */
@@ -287,7 +299,7 @@ if (runtimeSP->larger_sided_hyphobP == NULL)
 	ErrorMessage_ ("garlic", "InitRuntime_", "",
 	    "Failed to allocate memory for larger sided hydrophobicity!\n",
 	    "", "", "");
-	return -12;
+	return -13;
 	}
 runtimeSP->smaller_sided_hyphobP = (double *) calloc (elementsN, double_size);
 if (runtimeSP->smaller_sided_hyphobP == NULL)
@@ -295,7 +307,7 @@ if (runtimeSP->smaller_sided_hyphobP == NULL)
 	ErrorMessage_ ("garlic", "InitRuntime_", "",
 	    "Failed to allocate memory for smaller sided hydrophobicity!\n",
 	    "", "", "");
-	return -13;
+	return -14;
 	}
 
 /* Allocate memory for hydrophobicity function F1: */
@@ -306,7 +318,7 @@ if (runtimeSP->function1P == NULL)
 	ErrorMessage_ ("garlic", "InitRuntime_", "",
 		"Failed to allocate memory for function F1!\n",
 		"", "", "");
-	return -14;
+	return -15;
 	}
 
 /* Allocate memory for hydrophobicity function F2: */
@@ -317,7 +329,7 @@ if (runtimeSP->function2P == NULL)
 	ErrorMessage_ ("garlic", "InitRuntime_", "",
 		"Failed to allocate memory for function F2!\n",
 		"", "", "");
-	return -15;
+	return -16;
 	}
 
 /* Allocate memory for hydrophobicity function F3: */
@@ -328,7 +340,7 @@ if (runtimeSP->function3P == NULL)
 	ErrorMessage_ ("garlic", "InitRuntime_", "",
 		"Failed to allocate memory for function F3!\n",
 		"", "", "");
-	return -16;
+	return -17;
 	}
 
 /* Allocate memory for hydrophobicity function F4: */
@@ -339,7 +351,7 @@ if (runtimeSP->function4P == NULL)
 	ErrorMessage_ ("garlic", "InitRuntime_", "",
 		"Failed to allocate memory for function F4!\n",
 		"", "", "");
-	return -17;
+	return -18;
 	}
 
 /* Allocate memory for hydrophobicity function F5: */
@@ -350,7 +362,29 @@ if (runtimeSP->function5P == NULL)
 	ErrorMessage_ ("garlic", "InitRuntime_", "",
 		"Failed to allocate memory for function F5!\n",
 		"", "", "");
-	return -18;
+	return -19;
+	}
+
+/* Allocate memory for hydrophobicity function F6: */
+elementsN = MAXRESIDUES;
+runtimeSP->function6P = (double *) calloc (elementsN, double_size);
+if (runtimeSP->function6P == NULL)
+	{
+	ErrorMessage_ ("garlic", "InitRuntime_", "",
+		"Failed to allocate memory for function F6!\n",
+		"", "", "");
+	return -20;
+	}
+
+/* Allocate memory for hydrophobicity function F7: */
+elementsN = MAXRESIDUES;
+runtimeSP->function7P = (double *) calloc (elementsN, double_size);
+if (runtimeSP->function7P == NULL)
+	{
+	ErrorMessage_ ("garlic", "InitRuntime_", "",
+		"Failed to allocate memory for function F7!\n",
+		"", "", "");
+	return -21;
 	}
 
 /* Allocate memory for auxiliary integers: */
@@ -362,7 +396,7 @@ if (runtimeSP->auxiliaryIP == NULL)
                 "Failed to allocate memory",
                 " for auxiliary integers!\n",
                 "", "");
-        return -19;
+        return -22;
         }
 
 /* Allocate memory for auxiliary double values: */
@@ -374,7 +408,7 @@ if (runtimeSP->aux_doubleP == NULL)
 		"Failed to allocate memory",
 		" for auxiliary double values!\n",
 		"", "");
-	return -20;
+	return -23;
 	}
 
 /* Initialize the number of residues in the reference sequence buffer: */
@@ -388,7 +422,7 @@ if (runtimeSP->reference_sequenceP == NULL)
 	ErrorMessage_ ("garlic", "InitRuntime_", "",
 		"Failed to allocate the reference sequence buffer!\n",
 		"", "", "");
-	return -21;
+	return -24;
 	}
 
 /* Initialize the reference secondary structure length: */
@@ -403,7 +437,7 @@ if (runtimeSP->reference_sec_structureP == NULL)
 		"Failed to allocate",
 		" the reference secondary structure buffer!\n",
 		"", "");
-	return -22;
+	return -25;
 	}
 
 /* Allocate memory for reference serial numbers: */
@@ -415,7 +449,7 @@ if (runtimeSP->reference_serialIP == NULL)
 		"Failed to allocate memory",
 		" for reference residue serial numbers!\n",
 		"", "");
-	return -23;
+	return -26;
 	}
 
 /* Allocate memory for reference numeric residue codes: */
@@ -428,7 +462,7 @@ if (runtimeSP->reference_residue_codeIP == NULL)
 		"Failed to allocate memory",
 		" for reference numeric residue codes!\n",
 		"", "");
-        return -24;
+        return -27;
         }
 
 /* Allocate memory for reference hydrophobicity values: */
@@ -441,7 +475,7 @@ if (runtimeSP->reference_hydrophobicityP == NULL)
 		"Failed to allocate memory",
 		" for reference hydrophobicity values!\n",
 		"", "");
-	return -25;
+	return -28;
 	}
 
 /* Initialize the zoom factor: */
@@ -474,14 +508,17 @@ runtimeSP->sphere_radius = 8.0;
 runtimeSP->sliding_window_width = 11;
 
 /* Initialize flags related to hydrophobicity functions: */
-runtimeSP->average_hydrophobicityF = 0;
-runtimeSP->hydrophobic_momentF     = 0;
-runtimeSP->sided_hydrophobicityF   = 0;
-runtimeSP->function1F              = 0;
-runtimeSP->function2F              = 0;
-runtimeSP->function3F              = 0;
-runtimeSP->function4F              = 0;
-runtimeSP->function5F              = 0;
+runtimeSP->average_hydrophobicityF  = 0;
+runtimeSP->weighted_hydrophobicityF = 0;
+runtimeSP->hydrophobic_momentF      = 0;
+runtimeSP->sided_hydrophobicityF    = 0;
+runtimeSP->function1F		    = 0;
+runtimeSP->function2F		    = 0;
+runtimeSP->function3F		    = 0;
+runtimeSP->function4F		    = 0;
+runtimeSP->function5F		    = 0;
+runtimeSP->function6F		    = 0;
+runtimeSP->function7F		    = 0;
 
 /* Initialize range indices: */
 runtimeSP->range_startI = 0;
@@ -508,7 +545,7 @@ if (runtimeSP->template_atomSP == NULL)
                 "Failed to allocate memory for template atoms!\n",
                 "", "", "");
 	runtimeSP->max_template_atomsN = 0;
-        return -26;
+        return -29;
         }
 else runtimeSP->max_template_atomsN = MAXTEMPLATEATOMS;
 
@@ -549,7 +586,7 @@ if (runtimeSP->beta_cellSP == NULL)
 	ErrorMessage_ ("garlic", "InitRuntime_", "",
 		       "Failed to allocate memory for beta cells!\n",
 		       "", "", "");
-	return -27;
+	return -30;
 	}
 
 /* Return positive value on success: */
