@@ -1,4 +1,4 @@
-/* Copyright (C) 2000 Damir Zucic */
+/* Copyright (C) 2001 Damir Zucic */
 
 /*=============================================================================
 
@@ -45,7 +45,7 @@ for (i = 0; i < 13; i++)
 	}
 
 /* If this point is reached, the specified residue is apolar: */
-return 0;
+return -1;
 }
 
 /*===========================================================================*/
