@@ -56,14 +56,16 @@ Notes:
 /*======function prototypes:=================================================*/
 
 double		RotationAngle_ (ConfigS *, GUIS *, double);
-void		Rotate_ (MolComplexS *, int, ConfigS *, double, int);
+int		Rotate_ (MolComplexS *, int,
+			 RuntimeS *, ConfigS *, double, int);
 size_t		MainRefresh_ (MolComplexS *, int,
 			      RuntimeS *, ConfigS *, GUIS *,
 			      NearestAtomS *, size_t, unsigned int);
 int		ControlRefresh_ (MolComplexS *, ConfigS *, GUIS *);
 int		DockingRefresh_ (RuntimeS *, GUIS *);
 double		TranslationShift_ (ConfigS *, GUIS *, double);
-void		Translate_ (MolComplexS *, int, ConfigS *, double, int);
+void		Translate_ (MolComplexS *, int,
+			    RuntimeS *, ConfigS *, double, int);
 double		SlabShift_ (ConfigS *, GUIS *, double);
 void		MoveBackSlab_ (MolComplexS *, int, ConfigS *, double);
 void		MoveFrontSlab_ (MolComplexS *, int, ConfigS *, double);
@@ -90,14 +92,15 @@ int KeyPress_ (MolComplexS *mol_complexSP, int *mol_complexesNP,
 	       unsigned int *refreshIP,
 	       XKeyEvent *key_eventSP)
 {
-char			stringA[STRINGSIZE];
-KeySym			key_symID;
-XComposeStatus		compose_statusS;
-double			rotation_angle;
-double			shift;
-int			carriage_pos, comm_length;
-int			new_char;
-int			command_code;
+static char		stringA[STRINGSIZE];
+static KeySym		key_symID;
+static XComposeStatus	compose_statusS;
+static double		rotation_angle;
+static double		shift;
+static int		carriage_pos, comm_length;
+static int		new_char;
+static int		command_code;
+static int		n;
 
 /* Get the KeySym: */
 XLookupString (key_eventSP, stringA, STRINGSIZE, &key_symID, &compose_statusS);
@@ -135,8 +138,8 @@ switch (key_symID)
 	case XK_KP_Down:
 		(*refreshIP)++;
 		rotation_angle = RotationAngle_ (configSP, guiSP, 1.0);
-		Rotate_ (mol_complexSP, *mol_complexesNP, configSP,
-			 rotation_angle, 1);
+		Rotate_ (mol_complexSP, *mol_complexesNP,
+			 runtimeSP, configSP, rotation_angle, 1);
 		MainRefresh_ (mol_complexSP, *mol_complexesNP,
 			      runtimeSP, configSP, guiSP,
 			      *nearest_atomSPP, *pixelsNP, *refreshIP);
@@ -151,8 +154,8 @@ switch (key_symID)
 	case XK_KP_Up:
 		(*refreshIP)++;
 		rotation_angle = RotationAngle_ (configSP, guiSP, -1.0);
-		Rotate_ (mol_complexSP, *mol_complexesNP, configSP,
-			 rotation_angle, 1);
+		Rotate_ (mol_complexSP, *mol_complexesNP,
+			 runtimeSP, configSP, rotation_angle, 1);
 		MainRefresh_ (mol_complexSP, *mol_complexesNP,
 			      runtimeSP, configSP, guiSP,
 			      *nearest_atomSPP, *pixelsNP, *refreshIP);
@@ -166,8 +169,8 @@ switch (key_symID)
 	case XK_KP_Left:
 		(*refreshIP)++;
 		rotation_angle = RotationAngle_ (configSP, guiSP, +1.0);
-		Rotate_ (mol_complexSP, *mol_complexesNP, configSP,
-			 rotation_angle, 2);
+		Rotate_ (mol_complexSP, *mol_complexesNP,
+			 runtimeSP, configSP, rotation_angle, 2);
 		MainRefresh_ (mol_complexSP, *mol_complexesNP,
 			      runtimeSP, configSP, guiSP,
 			      *nearest_atomSPP, *pixelsNP, *refreshIP);
@@ -181,8 +184,8 @@ switch (key_symID)
 	case XK_KP_Right:
 		(*refreshIP)++;
 		rotation_angle = RotationAngle_ (configSP, guiSP, -1.0);
-		Rotate_ (mol_complexSP, *mol_complexesNP, configSP,
-			 rotation_angle, 2);
+		Rotate_ (mol_complexSP, *mol_complexesNP,
+			 runtimeSP, configSP, rotation_angle, 2);
 		MainRefresh_ (mol_complexSP, *mol_complexesNP,
 			      runtimeSP, configSP, guiSP,
 			      *nearest_atomSPP, *pixelsNP, *refreshIP);
@@ -196,8 +199,8 @@ switch (key_symID)
 	case XK_KP_Prior:
 		(*refreshIP)++;
 		rotation_angle = RotationAngle_ (configSP, guiSP, +1.0);
-		Rotate_ (mol_complexSP, *mol_complexesNP, configSP,
-			 rotation_angle, 3);
+		Rotate_ (mol_complexSP, *mol_complexesNP,
+			 runtimeSP, configSP, rotation_angle, 3);
 		MainRefresh_ (mol_complexSP, *mol_complexesNP,
 			      runtimeSP, configSP, guiSP,
 			      *nearest_atomSPP, *pixelsNP, *refreshIP);
@@ -211,8 +214,8 @@ switch (key_symID)
 	case XK_KP_Home:
 		(*refreshIP)++;
 		rotation_angle = RotationAngle_ (configSP, guiSP, -1.0);
-		Rotate_ (mol_complexSP, *mol_complexesNP, configSP,
-			 rotation_angle, 3);
+		Rotate_ (mol_complexSP, *mol_complexesNP,
+			 runtimeSP, configSP, rotation_angle, 3);
 		MainRefresh_ (mol_complexSP, *mol_complexesNP,
 			      runtimeSP, configSP, guiSP,
 			      *nearest_atomSPP, *pixelsNP, *refreshIP);
@@ -228,8 +231,8 @@ switch (key_symID)
 	case XK_KP_F4:
 		(*refreshIP)++;
 		shift = TranslationShift_ (configSP, guiSP, +1.0);
-		Translate_ (mol_complexSP, *mol_complexesNP, configSP,
-			    shift, 1);
+		Translate_ (mol_complexSP, *mol_complexesNP,
+			    runtimeSP, configSP, shift, 1);
 		MainRefresh_ (mol_complexSP, *mol_complexesNP,
 			      runtimeSP, configSP, guiSP,
 			      *nearest_atomSPP, *pixelsNP, *refreshIP);
@@ -241,8 +244,8 @@ switch (key_symID)
 	case XK_KP_F3:
 		(*refreshIP)++;
 		shift = TranslationShift_ (configSP, guiSP, -1.0);
-		Translate_ (mol_complexSP, *mol_complexesNP, configSP,
-			    shift, 1);
+		Translate_ (mol_complexSP, *mol_complexesNP,
+			    runtimeSP, configSP, shift, 1);
 		MainRefresh_ (mol_complexSP, *mol_complexesNP,
 			      runtimeSP, configSP, guiSP,
 			      *nearest_atomSPP, *pixelsNP, *refreshIP);
@@ -254,8 +257,8 @@ switch (key_symID)
 	case XK_KP_Separator:
 		(*refreshIP)++;
 		shift = TranslationShift_ (configSP, guiSP, +1.0);
-		Translate_ (mol_complexSP, *mol_complexesNP, configSP,
-			    shift, 2);
+		Translate_ (mol_complexSP, *mol_complexesNP,
+			    runtimeSP, configSP, shift, 2);
 		MainRefresh_ (mol_complexSP, *mol_complexesNP,
 			      runtimeSP, configSP, guiSP,
 			      *nearest_atomSPP, *pixelsNP, *refreshIP);
@@ -266,8 +269,8 @@ switch (key_symID)
 	case XK_KP_Subtract:
 		(*refreshIP)++;
 		shift = TranslationShift_ (configSP, guiSP, -1.0);
-		Translate_ (mol_complexSP, *mol_complexesNP, configSP,
-			    shift, 2);
+		Translate_ (mol_complexSP, *mol_complexesNP,
+			    runtimeSP, configSP, shift, 2);
 		MainRefresh_ (mol_complexSP, *mol_complexesNP,
 			      runtimeSP, configSP, guiSP,
 			      *nearest_atomSPP, *pixelsNP, *refreshIP);
@@ -279,8 +282,8 @@ switch (key_symID)
 	case XK_KP_Begin:
 		(*refreshIP)++;
 		shift = TranslationShift_ (configSP, guiSP, +1.0);
-		Translate_ (mol_complexSP, *mol_complexesNP, configSP,
-			    shift, 3);
+		Translate_ (mol_complexSP, *mol_complexesNP,
+			    runtimeSP, configSP, shift, 3);
 		MainRefresh_ (mol_complexSP, *mol_complexesNP,
 			      runtimeSP, configSP, guiSP,
 			      *nearest_atomSPP, *pixelsNP, *refreshIP);
@@ -292,8 +295,8 @@ switch (key_symID)
 	case XK_KP_Insert:
 		(*refreshIP)++;
 		shift = TranslationShift_ (configSP, guiSP, -1.0);
-		Translate_ (mol_complexSP, *mol_complexesNP, configSP,
-			    shift, 3);
+		Translate_ (mol_complexSP, *mol_complexesNP,
+			    runtimeSP, configSP, shift, 3);
 		MainRefresh_ (mol_complexSP, *mol_complexesNP,
 			      runtimeSP, configSP, guiSP,
 			      *nearest_atomSPP, *pixelsNP, *refreshIP);
@@ -436,15 +439,17 @@ switch (key_symID)
 			}
 		break;
 
-	/* Replace the current command with the previous one: */
+	/* Replace the current command with the previous one, if available: */
 	case XK_Up:
-		ReplaceCommand_ (runtimeSP, -1, guiSP);
+		n = ReplaceCommand_ (runtimeSP, -1, guiSP);
+		if (n < 0) break;
 		InputRefresh_ (guiSP, runtimeSP);
 		break;
 
 	/* Replace the current command with the next one (if available): */
 	case XK_Down:
-		ReplaceCommand_ (runtimeSP, +1, guiSP);
+		n = ReplaceCommand_ (runtimeSP, +1, guiSP);
+		if (n < 0) break;
 		InputRefresh_ (guiSP, runtimeSP);
 		break;
 
@@ -512,14 +517,18 @@ switch (key_symID)
 
 		/** Update and check the command index **/
 		/** and the  total number of commands: **/
-		runtimeSP->curr_commandI++;
+		runtimeSP->next_commandI++;
+		if (runtimeSP->next_commandI >= MAXCOMMSTRINGS - 1)
+			{
+			runtimeSP->next_commandI = 0;
+			}
 		if (runtimeSP->highest_commandI < MAXCOMMSTRINGS - 1)
+			{
 			runtimeSP->highest_commandI++;
-		if (runtimeSP->curr_commandI >= MAXCOMMSTRINGS - 1)
-			runtimeSP->curr_commandI = 0;
+			}
 
 		/** Update the old_commandI: **/
-		runtimeSP->old_commandI = runtimeSP->curr_commandI;
+		runtimeSP->old_commandI = runtimeSP->next_commandI;
 
 		/** Return command code to the caller: **/
 		return command_code;
