@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2003 Damir Zucic */
+/* Copyright (C) 2000-2006 Damir Zucic */
 
 /*=============================================================================
 
@@ -427,13 +427,6 @@ else if (edit_modeI == 4)
 		     runtimeSP, guiSP);
 	}
 
-/* If editing the angle chi1, draw the chi1 plot. If */
-/* editing both chi1 and chi2,  draw chi1-chi2 plot: */
-else if (edit_modeI == 7)
-	{
-	/*@@*/ /* THIS SHOULD BE DONE AS SOON AS POSSIBLE */
-	}
-
 /* Write some hints if there are no macromolecular complexes loaded: */
 if (mol_complexesN == 0) WriteHints_ (guiSP);
 
