@@ -38,6 +38,7 @@ Notes:
 #include <stdio.h>
 
 #include <string.h>
+#include <math.h>
 
 #include <X11/Xlib.h>
 #include <X11/Xutil.h>
@@ -58,6 +59,8 @@ int		PlotMouse_ (RuntimeS *, GUIS *,
 int		ComparisonMouse_ (RuntimeS *, GUIS *,
 				  NearestAtomS *, size_t,
 				  XMotionEvent *);
+int		ExtractN_ (VectorS *, AtomS *, size_t, size_t);
+int		ExtractC_ (VectorS *, AtomS *, size_t, size_t);
 
 /*======handle MotionNotify events:==========================================*/
 
@@ -90,6 +93,16 @@ int			residue_name_length, string_length;
 int			text_width;
 int			line_x0 = 0, line_x1 = 0;
 int			width, height;
+ResidueS		*central_residueSP;
+size_t			first_atomI, last_atomI;
+int			octantI;
+int			n;
+VectorS			N_vectorS, C_vectorS;
+double			delta_x, delta_y;
+double			rho, cos_angle, sin_angle, angle;
+int			top_left_x, top_left_y;
+
+/*------Ramachandran plot:---------------------------------------------------*/
 
 /* If main window contains Ramachandran plot: */
 if (guiSP->main_window_modeI == 1)
@@ -101,6 +114,8 @@ if (guiSP->main_window_modeI == 1)
 		       motion_eventSP);
     }
 
+/*------hydrophobicity plots:------------------------------------------------*/
+
 /* If main window contains hydrophobicity plots: */
 else if (guiSP->main_window_modeI == 4)
     {
@@ -109,6 +124,8 @@ else if (guiSP->main_window_modeI == 4)
 		       motion_eventSP);
     }
 
+/*------sequence comparison plot:--------------------------------------------*/
+
 /* If main window contains sequence comparison: */
 else if (guiSP->main_window_modeI == 5)
     {
@@ -117,9 +134,13 @@ else if (guiSP->main_window_modeI == 5)
 			     motion_eventSP);
     }
 
+/*---------------------------------------------------------------------------*/
+
 /* If the event came from child window, return zero: */
 if (motion_eventSP->subwindow != None) return 0;
 
+/*------output window:-------------------------------------------------------*/
+
 /* Pixel index: */
 pixelI = guiSP->main_win_free_area_width * motion_eventSP->y +
 	 motion_eventSP->x;
@@ -355,6 +376,8 @@ stringA[STRINGSIZE - 1] = '\0';
 XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
 	     screen_x0, screen_y0, stringA, strlen (stringA));
 
+/*------sequence neighborhood:-----------------------------------------------*/
+
 /* Write  the sequence neighborhood  of the */
 /* residue under the pointer, if requested: */
 if (configSP->show_sequence_neighborhoodF)
@@ -362,6 +385,8 @@ if (configSP->show_sequence_neighborhoodF)
     /* The central residue index: */
     central_residueI = curr_atomSP->residue_arrayI;
 
+    /*------draw text:-------------------------------------------------------*/
+
     /* Space half-width: */
     space_width = XTextWidth (guiSP->main_winS.fontSP, " ", 1);
     space_half_width = space_width / 2;
@@ -485,8 +510,130 @@ if (configSP->show_sequence_neighborhoodF)
     XDrawRectangle (guiSP->displaySP, guiSP->main_winS.ID, guiSP->theGCA[0],
 		    line_x0, 4,
 		    (unsigned int) width, (unsigned int) height);
+
+    /*------draw the small arrow:--------------------------------------------*/
+
+    /* Only the N and C atom of the central residue will be used. */
+    central_residueSP = curr_mol_complexSP->residueSP + central_residueI;
+    first_atomI = central_residueSP->residue_startI;
+    last_atomI  = central_residueSP->residue_endI;
+
+    /* Initialize the octant index: */
+    octantI = 8;
+
+    /* Formal, single pass loop: */
+    do
+	{
+	/* Try to extract the N atom coordinates: */
+	n = ExtractN_ (&N_vectorS,
+		       curr_mol_complexSP->atomSP, first_atomI, last_atomI);
+	if (n < 1) break;
+
+	/* Try to extract the C atom coordinates: */
+	n = ExtractC_ (&C_vectorS,
+		       curr_mol_complexSP->atomSP, first_atomI, last_atomI);
+
+	/* Now project the vector from N to C to the XY plane: */
+	delta_x = C_vectorS.x - N_vectorS.x;
+	delta_y = C_vectorS.y - N_vectorS.y;
+
+	/* Prepare sine and cosine of the angle: */
+	rho = sqrt (delta_x * delta_x + delta_y * delta_y);
+	if (rho < 0.001) break;
+	cos_angle = delta_x / rho;
+	if      (cos_angle <= -0.999) angle = 3.1415927;
+	else if (cos_angle >=  0.999) angle = 0.0;
+	else angle = acos (cos_angle);
+	sin_angle = delta_y / rho;
+	if (sin_angle < 0.0) angle = 6.2831853 - angle;
+
+	/* Identify the octant: */
+	if      (angle < 0.392699087) octantI = 0;
+	else if (angle < 1.178097262) octantI = 1;
+	else if (angle < 1.963495437) octantI = 2;
+	else if (angle < 2.748893609) octantI = 3;
+	else if (angle < 3.534291783) octantI = 4;
+	else if (angle < 4.319689957) octantI = 5;
+	else if (angle < 5.105088131) octantI = 6;
+	else if (angle < 5.890486305) octantI = 7;
+	else octantI = 0;
+
+	/* End of formal loop: */
+	} while (0);
+
+	/* Prepare the arrow position: */
+	top_left_x = guiSP->control_winS.x0 / 2 - 16;
+	top_left_y = 4 + height + 4;
+
+	/* Draw the proper arrow: */
+	switch (octantI)
+	    {
+	    case 0:
+		XCopyArea (guiSP->displaySP,
+			   guiSP->small_arrows_pixmapID, guiSP->main_winS.ID,
+			   guiSP->theGCA[0],
+			   0, 0, 32, 32, top_left_x, top_left_y);
+		break;
+
+	    case 1:
+		XCopyArea (guiSP->displaySP,
+			   guiSP->small_arrows_pixmapID, guiSP->main_winS.ID,
+			   guiSP->theGCA[0],
+			   0, 31, 32, 32, top_left_x, top_left_y);
+		break;
+
+	    case 2:
+		XCopyArea (guiSP->displaySP,
+			   guiSP->small_arrows_pixmapID, guiSP->main_winS.ID,
+			   guiSP->theGCA[0],
+			   0, 62, 32, 32, top_left_x, top_left_y);
+		break;
+
+	    case 3:
+		XCopyArea (guiSP->displaySP,
+			   guiSP->small_arrows_pixmapID, guiSP->main_winS.ID,
+			   guiSP->theGCA[0],
+			   0, 93, 32, 32, top_left_x, top_left_y);
+		break;
+
+	    case 4:
+		XCopyArea (guiSP->displaySP,
+			   guiSP->small_arrows_pixmapID, guiSP->main_winS.ID,
+			   guiSP->theGCA[0],
+			   0, 124, 32, 32, top_left_x, top_left_y);
+		break;
+
+	    case 5:
+		XCopyArea (guiSP->displaySP,
+			   guiSP->small_arrows_pixmapID, guiSP->main_winS.ID,
+			   guiSP->theGCA[0],
+			   0, 155, 32, 32, top_left_x, top_left_y);
+		break;
+
+	    case 6:
+		XCopyArea (guiSP->displaySP,
+			   guiSP->small_arrows_pixmapID, guiSP->main_winS.ID,
+			   guiSP->theGCA[0],
+			   0, 186, 32, 32, top_left_x, top_left_y);
+		break;
+
+	    case 7:
+		XCopyArea (guiSP->displaySP,
+			   guiSP->small_arrows_pixmapID, guiSP->main_winS.ID,
+			   guiSP->theGCA[0],
+			   0, 217, 32, 32, top_left_x, top_left_y);
+		break;
+
+	    default:
+		XCopyArea (guiSP->displaySP,
+			   guiSP->small_arrows_pixmapID, guiSP->main_winS.ID,
+			   guiSP->theGCA[0],
+			   0, 248, 32, 32, top_left_x, top_left_y);
+	    }
     }
 
+/*---------------------------------------------------------------------------*/
+
 /* Return positive value: */
 return 1;
 }
