@@ -146,7 +146,10 @@ XDrawString (guiSP->displaySP, guiSP->output_winS.ID, guiSP->theGCA[0],
 first_residueI = central_residueI - NEIGH_HALF_WIDTH;
 if (first_residueI < 0) first_residueI = 0;
 last_residueI = central_residueI + NEIGH_HALF_WIDTH;
-if (last_residueI > runtimeSP->residuesN) last_residueI = runtimeSP->residuesN;
+if (last_residueI > (int) runtimeSP->residuesN)
+	{
+	last_residueI = runtimeSP->residuesN;
+	}
 
 /* Prepare the string with the left part of the neighborhood: */
 stringA[0] = '\0';
