@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2002 Damir Zucic */
+/* Copyright (C) 2000-2006 Damir Zucic */
 
 /*=============================================================================
 
@@ -34,9 +34,9 @@ fprintf (stdout,
 "=========================================================================\n");
 fprintf (stdout, "\n");
 fprintf (stdout,
-"Garlic was written by Damir Zucic (zucic@garlic.mefos.hr) as a complement\n");
+"Garlic  was written by  Damir Zucic  (zucic@mefos.hr)  as a complement to\n");
 fprintf (stdout,
-"to other molecular visualization  programs, like rasmol (by Roger Sayle).\n");
+"other molecular  visualization  programs,  like rasmol  (by Roger Sayle).\n");
 fprintf (stdout,
 "It was written to simplify  the analysis of membrane proteins, but it can\n");
 fprintf (stdout,
@@ -109,7 +109,7 @@ fprintf (stdout,
 fprintf (stdout,
 "                        containing only the e-mail message header and the\n");
 fprintf (stdout,
-"                        word 'Hi!',to zucic@garlic.mefos.hr.  Please type\n");
+"                        word 'Hi!', to zucic@garlic.mefos.hr. Please type\n");
 fprintf (stdout,
 "                        garlic -r   if you are going to use this program.\n");
 fprintf (stdout,
@@ -239,7 +239,7 @@ fprintf (stdout,
 fprintf (stdout,
 "file should be kept in users home directory.  Note that this is  not  the\n");
 fprintf (stdout,
-"first directory to be searched for  .garlicrc file!  Up to six  pathnames\n");
+"first directory to be searched for  .garlicrc file! Up to seven pathnames\n");
 fprintf (stdout,
 "are tryed in the following order:\n");
 fprintf (stdout, "\n");
@@ -254,9 +254,11 @@ fprintf (stdout,
 fprintf (stdout,
 "                                   home directory.\n");
 fprintf (stdout,
-"/etc/garlicrc                   garlicrc in /etc, Debian linux; note that\n");
+"/usr/share/garlic/.garlicrc     ./garlicrc in  /usr/share/garlic (Linux).\n");
 fprintf (stdout,
-"                                   file name is garlicrc in this case!\n");
+"/etc/garlicrc                   garlicrc in /etc, Debian Linux; note that\n");
+fprintf (stdout,
+"                                   file name is  garlicrc  in  this case!\n");
 fprintf (stdout,
 "/usr/local/lib/garlic/.garlicrc .garlicrc  in  /usr/local/lib/garlic dir.\n");
 fprintf (stdout,
@@ -300,7 +302,7 @@ fprintf (stdout,
 fprintf (stdout,
 "Damir Zucic home page:                      http://garlic.mefos.hr/zucic\n");
 fprintf (stdout,
-"E-mail:                                     zucic@garlic.mefos.hr\n");
+"E-mail:                                     zucic@mefos.hr\n");
 fprintf (stdout,
 "=========================================================================\n");
 fprintf (stdout, "\n");
