@@ -26,8 +26,8 @@ void PrintVersion_ (void)
 {
 fprintf (stdout, "\n");
 fprintf (stdout, "==================================\n");
-fprintf (stdout, "garlic version 1.5\n");
-fprintf (stdout, "Release date: 2006/January/12\n");
+fprintf (stdout, "garlic version 1.6\n");
+fprintf (stdout, "Release date: 2006/X/X\n");
 fprintf (stdout, "==================================\n");
 fprintf (stdout, "\n");
 fprintf (stdout, "Compliant with PDB version 2.1");
@@ -36,7 +36,7 @@ fprintf (stdout,
 	 "Copyright (C) 2000-2006 Damir Zucic (zucic@garlic.mefos.hr).\n");
 fprintf (stdout, "Source code, documentation and binaries:\n");
 fprintf (stdout, "\n=====================================\n");
-fprintf (stdout, "  http://garlic.mefos.hr/garlic-1.5\n");
+fprintf (stdout, "  http://garlic.mefos.hr/garlic-1.6\n");
 fprintf (stdout, "=====================================\n\n");
 }
 
