@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2002 Damir Zucic */
+/* Copyright (C) 2000-2003 Damir Zucic */
 
 /*=============================================================================
 
@@ -224,7 +224,7 @@ while (fgets (lineA, line_size, fileP))
 		{
 		/* Check the line length  (do not */
 		/* forget that newline is there): */
-		if (strlen (lineA) < model_serial_end + 2) continue;
+		if ((int) strlen (lineA) < model_serial_end + 2) continue;
 
 		/* Try to read the model serial number: */
 		P = lineA + model_serial_start;
