@@ -1,4 +1,4 @@
-/* Copyright (C) 2001, 2002 Damir Zucic */
+/* Copyright (C) 2001-2003 Damir Zucic */
 
 /*=============================================================================
 
@@ -198,7 +198,7 @@ for (residueI = 0; residueI < total_residuesN; residueI++)
 /* Compare the number of selected residues with the number of */
 /* residues in  the main sequence buffer;  this function will */
 /* refuse to replace residues if these numbers are not equal: */
-if (selected_residuesN != runtimeSP->residuesN)
+if (selected_residuesN != (int) runtimeSP->residuesN)
 	{
 	sprintf (runtimeSP->messageA,
 		"%d resid. selected but sequence buffer contains %d!",
@@ -270,7 +270,7 @@ for (residueI = 0; residueI < total_residuesN; residueI++)
 	}
 
 /* Check the sequence in the main sequence buffer: */
-for (residueI = 0; residueI < runtimeSP->residuesN; residueI++)
+for (residueI = 0; residueI < (int) runtimeSP->residuesN; residueI++)
 	{
 	/* Prepare the pointer to the current residue name: */
 	new_residue_nameP = runtimeSP->sequenceP + residueI * max_length;
@@ -399,7 +399,7 @@ for (residueI = 0; residueI < total_residuesN; residueI++)
 	}
 
 /* Count the number of atoms which should be inserted: */
-for (residueI = 0; residueI < runtimeSP->residuesN; residueI++)
+for (residueI = 0; residueI < (int) runtimeSP->residuesN; residueI++)
 	{
 	/* Prepare the pointer to the current residue name: */
 	new_residue_nameP = runtimeSP->sequenceP + residueI * max_length;
@@ -442,7 +442,7 @@ for (residueI = 0; residueI < runtimeSP->residuesN; residueI++)
 new_atomsN = old_atomsN + inserted_atomsN - deleted_atomsN;
 
 /* Check the available storage and reallocate memory if necessary: */
-if (new_atomsN > curr_mol_complexSP->max_atomsN + 100)
+if (new_atomsN > (int) curr_mol_complexSP->max_atomsN + 100)
 	{
 	/* Prepare the number of bytes: */
 	new_memory_size = new_atomsN * atom_struct_size;
@@ -498,7 +498,7 @@ if (temporary_mol_complexSP->atomSP == NULL)
 	}
 
 /* Copy the required template residues: */
-for (residueI = 0; residueI < runtimeSP->residuesN; residueI++)
+for (residueI = 0; residueI < (int) runtimeSP->residuesN; residueI++)
 	{
 	/* The name of the residue which will be inserted: */
 	new_residue_nameP = runtimeSP->sequenceP + residueI * max_length;
@@ -592,7 +592,8 @@ for (residueI = 0; residueI < total_residuesN; residueI++)
 	/*------copy the residue sequence number:----------------------------*/
 
 	residue_sequenceI = old_first_atomSP->raw_atomS.residue_sequenceI;
-	for (atomI = new_atom_startI; atomI <= new_atom_endI; atomI++)
+	for (atomI = (int) new_atom_startI;
+	     atomI <= (int) new_atom_endI; atomI++)
 		{
 		/* Pointer to the current new atom: */
 		dest_atomSP = temporary_mol_complexSP->atomSP + atomI;
@@ -616,7 +617,8 @@ for (residueI = 0; residueI < total_residuesN; residueI++)
 	if (n < 2) continue;
 
 	/* Scan the new residue: */
-	for (atomI = new_atom_startI; atomI <= new_atom_endI; atomI++)
+	for (atomI = (int) new_atom_startI;
+	     atomI <= (int) new_atom_endI; atomI++)
 		{
 		/* Pointer to the current atom: */
 		atomSP = temporary_mol_complexSP->atomSP + atomI;
@@ -654,7 +656,8 @@ for (residueI = 0; residueI < total_residuesN; residueI++)
 	if (n < 1) continue;
 
 	/* Scan the new residue: */
-	for (atomI = new_atom_startI; atomI <= new_atom_endI; atomI++)
+	for (atomI = (int) new_atom_startI;
+	     atomI <= (int) new_atom_endI; atomI++)
 		{
 		/* Pointer to the current atom: */
 		atomSP = temporary_mol_complexSP->atomSP + atomI;
@@ -854,7 +857,7 @@ for (residueI = total_residuesN - 1; residueI >= 0; residueI--)
 
 		/* The number of atoms after the */
 		/* last atom of the old residue: */
-		if (current_atomsN > old_atom_endI)    /* Paranoid check */
+		if (current_atomsN > (int) old_atom_endI)  /* Paranoid check */
 			{
 			trailing_atomsN = current_atomsN - old_atom_endI - 1;
 			}
