@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2002 Damir Zucic */
+/* Copyright (C) 2000-2003 Damir Zucic */
 
 /*=============================================================================
 
@@ -78,7 +78,7 @@ int		selectedF = 1;
 
 /* Check is there anything in the sequence buffer: */
 residues2N = runtimeSP->residuesN;
-if (residues2N == 0) return 0;
+if (residues2N == 0) return (long) 0;
 
 /* The maximal residue name length: */
 max_length = RESNAMESIZE - 1;
