@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2002 Damir Zucic */
+/* Copyright (C) 2000-2003 Damir Zucic */
 
 /*=============================================================================
 
@@ -85,7 +85,7 @@ for (mol_complexI = 0; mol_complexI < mol_complexesN; mol_complexI++)
 	}
 
 /* Check how many atoms are selected: */
-if (selected_atomsN == 0) return 0;
+if (selected_atomsN == 0) return (long) 0;
 
 /* Calculate the geometric center position: */
 denom = 1.0 / (double) selected_atomsN;
