@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2003 Damir Zucic */
+/* Copyright (C) 2000-2006 Damir Zucic */
 
 /*=============================================================================
 
@@ -12,12 +12,15 @@ Purpose:
 	AROMATIC,  ALIPHATIC,  SMALL,  TINY,  POSITIVE,  NEGATIVE,  BASIC,
 	ACIDIC, CHARGED, MAIN_CHAIN, SIDE_CHAINS, HETERO, CIS, TRANS, BAD,
 	COMPLEMENT,  SEQUENCE,  SPHERE, ALTERNATE,  MODEL,  ABOVE,  BELOW,
-	TRIPLET, TM, PATTERN,  2C3, 2CZ3, 3C4, 3CZ4, 3C5, 3CZ5, 4C5, 4CZ5,
-	3C6, 3CZ6, 4C6, 4CZ6, 5C6, 5CZ6, 4C7, 4CZ7, 5C7, 5CZ7,  5C9, 5CZ9,
-	5P7 and 6P7.  Most of  these keywords  may be abbreviated to three
-	characters.  The exceptions are keywords HYDROPHOBIC (which may be
-	replaced by PHO or HYDROPHO),  2CZ3, 3CZ4, 3CZ5, 4CZ5, 3CZ6, 4CZ6,
-	5CZ6, 4CZ7, 5CZ7 and 5CZ9.
+	TRIPLET, TM, PATTERN, 2C3, 2CZ3, 2NZ3, 3C4, 3CZ4, 3NZ4, 3C5, 3CZ5,
+	3NZ5, 3P5, 4C5, 4CZ5, 4NZ5, 3C6, 3CZ6, 3NZ6, 4C6, 4CZ6, 4NZ6, 4P6,
+	5C6, 5CZ6, 5NZ6,  4C7, 4CZ7, 4NZ7, 5C7, 5CZ7, 5NZ7, 5P7, 6P7, 4C9,
+	4CZ9, 4NZ9, 5C9, 5CZ9, 5NZ9 and  $1.  Most keywords may be abbrev.
+	to 3 characters.  The exceptions are keywords HYDROPHOBIC  (it may
+	be replaced by  PHO or shortened to  HYDROPHO),  2CZ3, 2NZ3, 3CZ4,
+	3NZ4, 3CZ5, 3NZ5, 4CZ5, 4NZ5,  3CZ6, 3NZ6, 4CZ6, 4NZ6, 5CZ6, 5NZ6,
+	4CZ7, 4NZ7, 5CZ7, 5NZ7, 4CZ9, 5CZ9 and  5NZ9.  The keyword $1 is a
+	special selection keyword (not implemented yet, @@).
 
 Input:
 	(1) Pointer to MolComplexS structure, with macromol. complexes.
@@ -69,26 +72,41 @@ long		SelectTM_ (MolComplexS *, int, int);
 long		SelectPattern_ (MolComplexS *, int, RuntimeS *, int);
 long		Select2C3_ (MolComplexS *, int, int);
 long		Select2CZ3_ (MolComplexS *, int, int);
+long		Select2NZ3_ (MolComplexS *, int, int);
 long		Select3C4_ (MolComplexS *, int, int);
 long		Select3CZ4_ (MolComplexS *, int, int);
+long		Select3NZ4_ (MolComplexS *, int, int);
 long		Select3C5_ (MolComplexS *, int, int);
 long		Select3CZ5_ (MolComplexS *, int, int);
+long		Select3NZ5_ (MolComplexS *, int, int);
+long		Select3P5_ (MolComplexS *, int, int);
 long		Select4C5_ (MolComplexS *, int, int);
 long		Select4CZ5_ (MolComplexS *, int, int);
+long		Select4NZ5_ (MolComplexS *, int, int);
 long		Select3C6_ (MolComplexS *, int, int);
 long		Select3CZ6_ (MolComplexS *, int, int);
+long		Select3NZ6_ (MolComplexS *, int, int);
 long		Select4C6_ (MolComplexS *, int, int);
 long		Select4CZ6_ (MolComplexS *, int, int);
+long		Select4NZ6_ (MolComplexS *, int, int);
+long		Select4P6_ (MolComplexS *, int, int);
 long		Select5C6_ (MolComplexS *, int, int);
 long		Select5CZ6_ (MolComplexS *, int, int);
+long		Select5NZ6_ (MolComplexS *, int, int);
 long		Select4C7_ (MolComplexS *, int, int);
 long		Select4CZ7_ (MolComplexS *, int, int);
+long		Select4NZ7_ (MolComplexS *, int, int);
 long		Select5C7_ (MolComplexS *, int, int);
 long		Select5CZ7_ (MolComplexS *, int, int);
-long		Select5C9_ (MolComplexS *, int, int);
-long		Select5CZ9_ (MolComplexS *, int, int);
+long		Select5NZ7_ (MolComplexS *, int, int);
 long		Select5P7_ (MolComplexS *, int, int);
 long		Select6P7_ (MolComplexS *, int, int);
+long		Select4C9_ (MolComplexS *, int, int);
+long		Select4CZ9_ (MolComplexS *, int, int);
+long		Select4NZ9_ (MolComplexS *, int, int);
+long		Select5C9_ (MolComplexS *, int, int);
+long		Select5CZ9_ (MolComplexS *, int, int);
+long		Select5NZ9_ (MolComplexS *, int, int);
 int		Include_ (SelectS *, char *);
 int		Exclude_ (SelectS *, char *);
 long		ApplySelection_ (MolComplexS *, int,
@@ -301,6 +319,14 @@ else if (strstr (tokenA, "2CZ3") == tokenA)
 	return selected_atomsN;
 	}
 
+/** 2NZ3 (two or more negative or zwitterionic in a fragment of three): **/
+else if (strstr (tokenA, "2NZ3") == tokenA)
+	{
+	selected_atomsN = Select2NZ3_ (mol_complexSP, mol_complexesN,
+				       selection_modeI);
+	return selected_atomsN;
+	}
+
 /** 3C4 (three or more charged in a fragment of four residues): **/
 else if (strstr (tokenA, "3C4") == tokenA)
 	{
@@ -317,6 +343,14 @@ else if (strstr (tokenA, "3CZ4") == tokenA)
 	return selected_atomsN;
 	}
 
+/** 3NZ4 (three or more negative or zwitterionic in a fragment of four): **/
+else if (strstr (tokenA, "3NZ4") == tokenA)
+	{
+	selected_atomsN = Select3NZ4_ (mol_complexSP, mol_complexesN,
+				       selection_modeI);
+	return selected_atomsN;
+	}
+
 /** 3C5 (three or more charged in a fragment of five residues): **/
 else if (strstr (tokenA, "3C5") == tokenA)
 	{
@@ -333,6 +367,14 @@ else if (strstr (tokenA, "3CZ5") == tokenA)
 	return selected_atomsN;
 	}
 
+/** 3NZ5 (three or more negative or zwitterionic in a fragment of five): **/
+else if (strstr (tokenA, "3NZ5") == tokenA)
+	{
+	selected_atomsN = Select3NZ5_ (mol_complexSP, mol_complexesN,
+				       selection_modeI);
+	return selected_atomsN;
+	}
+
 /** 4C5 (four or more charged in a fragment of five residues): **/
 else if (strstr (tokenA, "4C5") == tokenA)
 	{
@@ -349,7 +391,15 @@ else if (strstr (tokenA, "4CZ5") == tokenA)
 	return selected_atomsN;
 	}
 
-/** 3C6 (three of more charged in a fragment of six residues): **/
+/** 4NZ5 (four or more negative or zwitterionic in a fragment of five): **/
+else if (strstr (tokenA, "4NZ5") == tokenA)
+	{
+	selected_atomsN = Select4NZ5_ (mol_complexSP, mol_complexesN,
+				       selection_modeI);
+	return selected_atomsN;
+	}
+
+/** 3C6 (three or more charged in a fragment of six residues): **/
 else if (strstr (tokenA, "3C6") == tokenA)
 	{
 	selected_atomsN = Select3C6_ (mol_complexSP, mol_complexesN,
@@ -357,7 +407,7 @@ else if (strstr (tokenA, "3C6") == tokenA)
 	return selected_atomsN;
 	}
 
-/** 3CZ6 (three of more charged or zwitterionic in a fragment of six): **/
+/** 3CZ6 (three or more charged or zwitterionic in a fragment of six): **/
 else if (strstr (tokenA, "3CZ6") == tokenA)
 	{
 	selected_atomsN = Select3CZ6_ (mol_complexSP, mol_complexesN,
@@ -365,7 +415,15 @@ else if (strstr (tokenA, "3CZ6") == tokenA)
 	return selected_atomsN;
 	}
 
-/** 4C6 (four of more charged in a fragment of six residues): **/
+/** 3NZ6 (three or more negative or zwitterionic in a fragment of six): **/
+else if (strstr (tokenA, "3NZ6") == tokenA)
+	{
+	selected_atomsN = Select3NZ6_ (mol_complexSP, mol_complexesN,
+				       selection_modeI);
+	return selected_atomsN;
+	}
+
+/** 4C6 (four or more charged in a fragment of six residues): **/
 else if (strstr (tokenA, "4C6") == tokenA)
 	{
 	selected_atomsN = Select4C6_ (mol_complexSP, mol_complexesN,
@@ -373,7 +431,7 @@ else if (strstr (tokenA, "4C6") == tokenA)
 	return selected_atomsN;
 	}
 
-/** 4CZ6 (four of more charged or zwitterionic in a fragment of six): **/
+/** 4CZ6 (four or more charged or zwitterionic in a fragment of six): **/
 else if (strstr (tokenA, "4CZ6") == tokenA)
 	{
 	selected_atomsN = Select4CZ6_ (mol_complexSP, mol_complexesN,
@@ -381,7 +439,23 @@ else if (strstr (tokenA, "4CZ6") == tokenA)
 	return selected_atomsN;
 	}
 
-/** 5C6 (five of more charged in a fragment of six residues): **/
+/** 4NZ6 (four or more negative or zwitterionic in a fragment of six): **/
+else if (strstr (tokenA, "4NZ6") == tokenA)
+	{
+	selected_atomsN = Select4NZ6_ (mol_complexSP, mol_complexesN,
+				       selection_modeI);
+	return selected_atomsN;
+	}
+
+/** 4P6 (four or more polar in a fragment of six): **/
+else if (strstr (tokenA, "4P6") == tokenA)
+	{
+	selected_atomsN = Select4P6_ (mol_complexSP, mol_complexesN,
+				      selection_modeI);
+	return selected_atomsN;
+	}
+
+/** 5C6 (five or more charged in a fragment of six residues): **/
 else if (strstr (tokenA, "5C6") == tokenA)
 	{
 	selected_atomsN = Select5C6_ (mol_complexSP, mol_complexesN,
@@ -389,7 +463,7 @@ else if (strstr (tokenA, "5C6") == tokenA)
 	return selected_atomsN;
 	}
 
-/** 5CZ6 (five of more charged or zwitterionic in a fragment of six): **/
+/** 5CZ6 (five or more charged or zwitterionic in a fragment of six): **/
 else if (strstr (tokenA, "5CZ6") == tokenA)
 	{
 	selected_atomsN = Select5CZ6_ (mol_complexSP, mol_complexesN,
@@ -397,6 +471,14 @@ else if (strstr (tokenA, "5CZ6") == tokenA)
 	return selected_atomsN;
 	}
 
+/** 5NZ6 (five or more negative or zwitterionic in a fragment of six): **/
+else if (strstr (tokenA, "5NZ6") == tokenA)
+	{
+	selected_atomsN = Select5NZ6_ (mol_complexSP, mol_complexesN,
+				       selection_modeI);
+	return selected_atomsN;
+	}
+
 /** 4C7 (four or more charged in a fragment of seven residues): **/
 else if (strstr (tokenA, "4C7") == tokenA)
 	{
@@ -413,6 +495,14 @@ else if (strstr (tokenA, "4CZ7") == tokenA)
 	return selected_atomsN;
 	}
 
+/** 4NZ7 (four or more negative or zwitterionic in a fragment of seven): **/
+else if (strstr (tokenA, "4NZ7") == tokenA) 
+	{
+	selected_atomsN = Select4NZ7_ (mol_complexSP, mol_complexesN,
+				       selection_modeI);
+	return selected_atomsN;
+	}
+
 /** 5C7 (five or more charged in a fragment of seven residues): **/
 else if (strstr (tokenA, "5C7") == tokenA) 
 	{
@@ -429,6 +519,62 @@ else if (strstr (tokenA, "5CZ7") == tokenA)
 	return selected_atomsN;
 	}
 
+/** 5NZ7 (five or more negative or zwitterionic in a fragment of seven): **/
+else if (strstr (tokenA, "5NZ7") == tokenA) 
+	{       
+	selected_atomsN = Select5NZ7_ (mol_complexSP, mol_complexesN,
+				       selection_modeI);
+	return selected_atomsN;
+	}
+
+/** 3P5 (three or more polar in a fragment of five residues): **/
+else if (strstr (tokenA, "3P5") == tokenA)
+	{
+	selected_atomsN = Select3P5_ (mol_complexSP, mol_complexesN,
+				      selection_modeI);
+	return selected_atomsN;
+	}
+
+/** 5P7 (five or more polar in a fragment of seven residues): **/
+else if (strstr (tokenA, "5P7") == tokenA)
+        {
+        selected_atomsN = Select5P7_ (mol_complexSP, mol_complexesN,
+				      selection_modeI);
+        return selected_atomsN;
+        }
+
+/** 6P7 (six or more polar in a fragment of seven residues): **/
+else if (strstr (tokenA, "6P7") == tokenA)
+	{
+	selected_atomsN = Select6P7_ (mol_complexSP, mol_complexesN,
+				      selection_modeI);
+	return selected_atomsN;
+	}
+
+/** 4C9 (four or more charged in a fragment of nine residues): **/
+else if (strstr (tokenA, "4C9") == tokenA)
+	{
+	selected_atomsN = Select4C9_ (mol_complexSP, mol_complexesN,
+				      selection_modeI);
+	return selected_atomsN;
+	}
+
+/** 4CZ9 (four or more charged or zwitterionic in a fragment of nine): **/
+else if (strstr (tokenA, "4CZ9") == tokenA)
+	{
+	selected_atomsN = Select4CZ9_ (mol_complexSP, mol_complexesN,
+				       selection_modeI);
+	return selected_atomsN;
+	}
+
+/** 4NZ9 (four or more negative or zwitterionic in a fragment of nine): **/
+else if (strstr (tokenA, "4NZ9") == tokenA)
+	{
+	selected_atomsN = Select4NZ9_ (mol_complexSP, mol_complexesN,
+				       selection_modeI);
+	return selected_atomsN;
+	}
+
 /** 5C9 (five or more charged in a fragment of nine residues): **/
 else if (strstr (tokenA, "5C9") == tokenA) 
 	{
@@ -445,19 +591,11 @@ else if (strstr (tokenA, "5CZ9") == tokenA)
 	return selected_atomsN;
 	}
 
-/** 5P7 (five or more polar in a fragment of seven residues): **/
-else if (strstr (tokenA, "5P7") == tokenA)
-        {
-        selected_atomsN = Select5P7_ (mol_complexSP, mol_complexesN,
-				      selection_modeI);
-        return selected_atomsN;
-        }
-
-/** 6P7 (six or more polar in a fragment of seven residues): **/
-else if (strstr (tokenA, "6P7") == tokenA)
+/** 5NZ9 (five or more negative or zwitterionic in a fragment of nine): **/
+else if (strstr (tokenA, "5NZ9") == tokenA)
 	{
-	selected_atomsN = Select6P7_ (mol_complexSP, mol_complexesN,
-				      selection_modeI);
+	selected_atomsN = Select5NZ9_ (mol_complexSP, mol_complexesN,
+				       selection_modeI);
 	return selected_atomsN;
 	}
 
