@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2002 Damir Zucic */
+/* Copyright (C) 2000-2003 Damir Zucic */
 
 /*=============================================================================
 
@@ -130,7 +130,7 @@ for (atomI = 0; atomI < atomsN; atomI++)
 		/** Prepare and check the combined index: **/
 		combinedI = atomI + neighborI;
 		if (combinedI < 0) continue;
-		if (combinedI >= atomsN) break;
+		if (combinedI >= (int) atomsN) break;
 
 		/** If combined index is good, use it as array index: **/
 		neighbor_arrayI = combinedI;
