@@ -1189,6 +1189,7 @@ typedef struct		/* RuntimeS */
 	double		sphere_radius;            /* angstroms */
 	int		sliding_window_width;     /* residues  */
 	int		average_hydrophobicityF;  /* Average hydrophobicity  */
+	int		weighted_hydrophobicityF; /* Weighted hydrophobicity */
 	int		hydrophobic_momentF;      /* Hydrophobic moment      */
 	int		sided_hydrophobicityF;    /* Two sided-h. functions  */
 	int		function1F;               /* 1 = draw function F1    */
@@ -1196,6 +1197,8 @@ typedef struct		/* RuntimeS */
 	int		function3F;               /* 1 = draw function F3    */
 	int		function4F;               /* 1 = draw function F4    */
 	int		function5F;               /* 1 = draw function F5    */
+	int		function6F;               /* 1 = draw function F6    */
+	int		function7F;               /* 1 = draw function F7    */
 
 	size_t		sequence_buffer_size;       /* Size of seq. buffer   */
 	size_t		residuesN;                  /* Sequence length       */
@@ -1206,6 +1209,7 @@ typedef struct		/* RuntimeS */
 	int		*serialIP;                  /* Serial numbers        */
 	int		*residue_codeIP;            /* Numeric residue codes */
 	double		*hydrophobicityP;           /* Hydrophobicity values */
+	double		*weighted_hydrophobicityP;  /* Weighted hyd. values  */
 	double		*average_hydrophobicityP;   /* For given  win. width */
 	double		*hydrophobic_momentP;       /* Absolute value        */
 	double		*larger_sided_hyphobP;      /* Sided h.,  upper line */
@@ -1215,6 +1219,8 @@ typedef struct		/* RuntimeS */
 	double		*function3P;                /* Hydroph. function F3  */
 	double		*function4P;                /* Hydroph. function F4  */
 	double		*function5P;                /* Hydroph. function F5  */
+	double		*function6P;                /* Hydroph. function F6  */
+	double		*function7P;                /* Hydroph. function F7  */
 
 	int		*auxiliaryIP;               /* Aux. integer storage  */
 	double		*aux_doubleP;               /* Aux. double storage   */
