@@ -1,11 +1,11 @@
-/* Copyright (C) 2000 Damir Zucic */
+/* Copyright (C) 2000, 2001 Damir Zucic */
 
 /*=============================================================================
 
 				vector_product.c
 
 Purpose:
-	Calculate the vector product of two vectors.
+	Calculate the vector product of two vectors (v3 = v1 x v2).
 
 Input:
 	(1) Pointer to VectorS structure,  where the result  will be stored.
