@@ -1,4 +1,4 @@
-/* Copyright (C) 2000-2002 Damir Zucic */
+/* Copyright (C) 2000-2003 Damir Zucic */
 
 /*=============================================================================
 
@@ -107,9 +107,16 @@ if (strstr (stringP, " OFF"))
 /* drawn clockwise (this gives the bottom view of the corresponding helix). */
 if (strstr (stringP, " CLO")) runtimeSP->wheel_clockwiseF = 1;
 
-/* Initialize the range indices: */
-runtimeSP->range_startI = *runtimeSP->serialIP;
-runtimeSP->range_endI   = *(runtimeSP->serialIP + runtimeSP->residuesN - 1);
+/* Initialize the range of residue array indices: */
+runtimeSP->range_startI = 0;
+if (runtimeSP->residuesN >= 1)
+	{
+	runtimeSP->range_endI = (int) runtimeSP->residuesN - 1;
+	}
+else
+	{
+	runtimeSP->range_endI = 0;
+	}
 
 /* Scan the string for digits; if it contains at least one */
 /* digit, try to extract two integers (the range indices): */
@@ -144,7 +151,7 @@ if (digit_foundF)
 		}
 
 	/* If indices were successfully read, check them: */
-	if (residue2I < residue1I)
+	if ((residue1I < 1) || (residue2I < residue1I))
 		{
 		strcpy (runtimeSP->messageA, "Bad range (check indices)!");
 		runtimeSP->message_length = strlen (runtimeSP->messageA);
@@ -152,8 +159,8 @@ if (digit_foundF)
 		}
 
 	/* Store the extracted indices: */
-	runtimeSP->range_startI = (size_t) residue1I;
-	runtimeSP->range_endI   = (size_t) residue2I;
+	runtimeSP->range_startI = residue1I - 1;
+	runtimeSP->range_endI = residue2I - 1;
 	}
 
 /* Set the main window drawing mode index: */
