@@ -54,7 +54,7 @@ XDrawString (guiSP->displaySP, guiSP->main_hidden_pixmapID, guiSP->theGCA[0],
 screen_x = 40;
 
 screen_y += delta_y;
-strcpy (stringA, "http://garlic.mefos.hr/garlic-1.5");
+strcpy (stringA, "http://garlic.mefos.hr/garlic-1.6");
 XDrawString (guiSP->displaySP, guiSP->main_hidden_pixmapID, guiSP->theGCA[0],
 	     screen_x, screen_y, stringA, strlen (stringA));
 
@@ -65,19 +65,6 @@ strcpy (stringA, "Author: http://garlic.mefos.hr/zucic");
 XDrawString (guiSP->displaySP, guiSP->main_hidden_pixmapID, guiSP->theGCA[0],
 	     screen_x, screen_y, stringA, strlen (stringA));
 
-screen_y += 2 * delta_y;
-strcpy (stringA, "Garlic development is supported as Project #0219031 by");
-XDrawString (guiSP->displaySP, guiSP->main_hidden_pixmapID, guiSP->theGCA[0],
-	     screen_x, screen_y, stringA, strlen (stringA));
-
-screen_x = 40;
-
-screen_y += delta_y;
-strcpy (stringA,
-	"The Ministry of Science and Technology, Republic of Croatia");
-XDrawString (guiSP->displaySP, guiSP->main_hidden_pixmapID, guiSP->theGCA[0],
-	     screen_x, screen_y, stringA, strlen (stringA));
-
 /* Change the text color (yellow): */
 XSetForeground (guiSP->displaySP, guiSP->theGCA[0], guiSP->yellow_colorID);
 
